
body#media-upload ul#sidemenu {
	left: auto;
	right: 0;
}

#basic .align .field label {
	display: block;
	float: right;
	padding: 0 24px 0 0;
	margin: 5px 3px 5px 5px; 
}

.align .field input {
	display: block;
	float: right;
	margin: 5px 15px 5px 0;
}

tr.image-size label {
	margin: 0;
}

tr.image-size input {
	margin: 3px 15px 0 5px;
}

.image-align-none-label,
.image-align-left-label,
.image-align-center-label,
.image-align-right-label {
	background-position: center right;
}

#media-upload .describe th.label {
	text-align: right;
}

.show-align,
.alignright,
#img_size {
	float: left;
}

tr.image-size label,
tr.image-size input,
#img_dim label,
#img_dim input,
#img_prop label,
#img_prop input,
#img_size_div,
.alignleft {
	float: right;
}

#img_dim label,
#img_prop label {
	margin: 5px 0pt;
}

#img_dim input,
#img_prop input {
	margin: 0 5px 0 10px;
}

#img_size_title {
	text-align: left;
}
