textarea,
input,
select {
	border-width: 1px;
	border-style: solid;
	-moz-border-radius: 4px;
	-khtml-border-radius: 4px;
	-webkit-border-radius: 4px;
	border-radius: 4px;
}

input[type="checkbox"],
input[type="radio"],
input[type="image"] {
	border: 0 none;
}

p,
ul,
ol,
blockquote,
input,
select {
	font-size: 12px;
}

select option {
	padding: 2px;
}

.plugins .name,
#pass-strength-result.strong,
#pass-strength-result.short,
.button-highlighted,
#quicktags #ed_strong,
#ed_reply_toolbar #ed_reply_strong {
	font-weight: bold;
}

.plugins p {
	margin: 0 4px;
	padding: 0;
}

.plugins .desc p {
	margin: 0 0 8px;
}

.plugins td.desc {
	line-height: 1.5em;
}

.plugins .desc ul,
.plugins .desc ol {
	margin: 0 0 0 2em;
}

.plugins .desc ul {
	list-style-type: disc;
}

.plugins .action-links { 
	white-space: nowrap;
}

.plugins .row-actions-visible {
	padding: 0;
}

.widefat tbody.plugins th.check-column {
	padding: 7px 0;
}

.widefat .plugins td,
.widefat .plugins th {
	border-bottom: 0 none;
}

#install-plugins .plugins td,
#install-plugins .plugins th {
	border-bottom-style: solid;
	border-bottom-width: 1px;
}

.plugins .inactive td,
.plugins .inactive th,
.plugins .active td,
.plugins .active th {
	border-top-style: solid;
	border-top-width: 1px;
	padding: 5px 7px 0;
}

#wpbody-content .plugins .plugin-title {
	padding-right: 12px;
}

.plugins .second td,
.plugins .second th {
	border-top: 0 none;
	padding: 0 7px 5px;
}

.plugins-php .widefat tfoot th,
.plugins-php .widefat tfoot td {
	border-top-style: solid;
	border-top-width: 1px;
}

.import-system {
	font-size: 16px;
}

.anchors {
	margin: 10px 20px 10px 20px;
}

table#availablethemes {
	border-spacing: 0;
	border-width: 1px 0;
	border-style: solid none;
	margin: 10px auto;
	width: 100%;
}

td.available-theme {
	vertical-align: top;
	width: 240px;
	margin: 0;
	padding: 20px;
	text-align: left;
}

table#availablethemes td {
	border-width: 0 1px 1px;
	border-style: none solid solid;
}

table#availablethemes td.right,
table#availablethemes td.left  {
	border-right: 0 none;
	border-left: 0 none;
}

table#availablethemes td.bottom {
	border-bottom: 0 none;
}

.available-theme a.screenshot {
	width: 240px;
	height: 180px;
	display: block;
	border-width: 1px;
	border-style: solid;
	margin-bottom: 10px;
	overflow: hidden;
}

.available-theme img {
	width: 240px;
}

.available-theme h3 {
	margin: 15px 0 5px;
}

#current-theme {
	margin: 1em 0 1.5em;
}

#current-theme a {
	border-bottom: none;
}

#current-theme h3 {
	font-size: 17px;
	font-weight: normal;
	margin: 0;
}

#current-theme .theme-description {
	margin-top: 5px;
}

#current-theme img {
	float: left;
	border-width: 1px;
	border-style: solid;
	margin-right: 1em;
	margin-bottom: 1.5em;
	width: 150px;
}

#TB_window #TB_title a.tb-theme-preview-link,
#TB_window #TB_title a.tb-theme-preview-link:visited {
	font-weight: bold;
	text-decoration: none;
}

#TB_window #TB_title {
	background-color: #222;
	color: #cfcfcf;
}

.checkbox {
	border: none;
	margin: 0;
	padding: 0;
}

.code, code {
	font-family: Consolas, Monaco, Courier, monospace;
}

kbd, code {
	padding: 1px 3px;
	margin: 0 1px;
	font-size: 11px;
}

.commentlist li {
	padding: 1em 1em .2em;
	margin: 0;
	border-bottom-width: 1px;
	border-bottom-style: solid;
}

.commentlist li li {
	border-bottom: 0;
	padding: 0;
}

.commentlist p {
	padding: 0;
	margin: 0 0 .8em;
}

.post-categories {
	display: inline;
	margin: 0;
	padding: 0;
}

.post-categories li {
	display: inline;
}

.quicktags, .search {
	font: 12px Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
}

.submit {
	padding: 1.5em 0;
	margin: 5px 0;
	-moz-border-radius: 0 0 3px 3px;
	-webkit-border-bottom-left-radius: 3px;
	-webkit-border-bottom-right-radius: 3px;
	-khtml-border-bottom-left-radius: 3px;
	-khtml-border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px;
	border-bottom-right-radius: 3px;
}

form p.submit a.cancel:hover {
	text-decoration: none;
}

#submitdiv h3,
#pagesubmitdiv h3 {
	margin-bottom: 0 !important;
}

#misc-publishing-actions {
	padding: 6px 0 16px 0;
}

.misc-pub-section {
	padding: 6px;
	border-bottom-width: 1px;
	border-bottom-style: solid;
}

.misc-pub-section-last {
	border-bottom: 0 none;
}

#minor-publishing-actions {
	padding: 6px;
	text-align: right;
}

#minor-publishing {
	border-bottom-width: 1px;
	border-bottom-style: solid;
}

#save-post {
	float: left;
}

.preview {
	float: right;
}

#major-publishing-actions {
	padding: 6px;
	clear: both;
	border-top: none;
}

#minor-publishing-actions input,
#major-publishing-actions input,
#minor-publishing-actions .preview {
	min-width: 80px;
	text-align: center;
}

#delete-action {
	line-height: 25px;
	vertical-align: middle;
	text-align: left;
	float: left;
}

#publishing-action {
	text-align: right;
	float: right;
}

#post-body #minor-publishing {
	padding-bottom: 10px;
}

#post-body #misc-publishing-actions {
	padding: 0;
}

#post-body .misc-pub-section {
	border-right-width: 1px;
	border-right-style: solid;
	border-bottom: 0 none;
	min-height: 30px;
	float: left;
	max-width: 32%;
}

#post-body .misc-pub-section-last {
	border-right: 0;
}

#sticky-span {
	margin-left: 18px;
}

#post-status-display,
#post-visibility-display {
	font-weight: bold;
}

.side-info {
	margin: 0;
	padding: 4px;
	font-size: 11px;
}

.side-info h5 {
	padding-bottom: 7px;
	font-size: 14px;
	margin: 12px 2px 5px;
	border-bottom-width: 1px;
	border-bottom-style: solid;
}

.side-info ul {
	margin: 0;
	padding-left: 18px;
	list-style: square;
}

.submit input,
.button,
.button-primary,
.button-secondary,
.button-highlighted,
#postcustomstuff .submit input {
	text-decoration: none;
	font-size: 11px !important;
	line-height: 16px;
	padding: 2px 8px;
	cursor: pointer;
	border-width: 1px;
	border-style: solid;
	-moz-border-radius: 11px;
	-khtml-border-radius: 11px;
	-webkit-border-radius: 11px;
	border-radius: 11px;
	-moz-box-sizing: content-box;
	-webkit-box-sizing: content-box;
	-khtml-box-sizing: content-box;
	box-sizing: content-box;
}

a.button,
a.button-primary,
a.button-secondary {
	line-height: 1.2em;
	-webkit-border-radius: 10px;
	padding: 4px 10px;
	white-space: nowrap;
}

#doaction,
#doaction2 {
	margin-right: 8px;
}

.tablenav select[name="action"],
.tablenav select[name="action2"] {
	width: 120px;
}

.tablenav select[name="m"] {
	width: 120px;
}

.tablenav select#cat {
	width: 150px;
}

#wpcontent select {
	padding: 2px;
	height: 2em;
	font-size: 11px;
}

#wpcontent option {
	padding: 2px;
}

#timezone_string option {
	margin-left: 1em;
}

.approve {
	display: none;
}

.unapproved .approve, .spam .approve {
	display: inline;
}

.unapproved .unapprove {
	display: none;
}

.narrow {
	width: 70%;
	margin-bottom: 40px;
}

.narrow p {
	line-height: 150%;
}

textarea.all-options, input.all-options {
	width: 250px;
}

#namediv table {
	width: 100%;
}

#namediv td.first {
	width: 10px;
	white-space: nowrap;
}

#namediv input {
	width: 98%;
}

#namediv p {
	margin: 10px 0;
}

#wpbody-content .metabox-holder {
	padding-top: 10px;
}

#content {
	margin: 0;
	width: 100%;
}

#editorcontainer #content {
	padding: 6px;
	line-height: 150%;
	border: 0 none;
	outline: none;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	-khtml-box-sizing: border-box;
	box-sizing: border-box;
}

#editorcontainer,
#quicktags {
	border-style: solid;
	border-width: 1px;
	border-collapse: separate;
	-moz-border-radius: 6px 6px 0 0;
	-webkit-border-top-right-radius: 6px;
	-webkit-border-top-left-radius: 6px;
	-khtml-border-top-right-radius: 6px;
	-khtml-border-top-left-radius: 6px;
	border-top-right-radius: 6px;
	border-top-left-radius: 6px;
}

#quicktags {
	padding: 0;
	margin-bottom: -3px;
	border-bottom-width: 3px;
	background-image: url("images/ed-bg.gif");
	background-position: left top;
	background-repeat: repeat-x;
}

#quicktags #ed_toolbar {
	padding: 2px 4px 0;
}

#ed_toolbar input,
#ed_reply_toolbar input {
	margin: 3px 1px 4px;
	line-height: 18px;
	display: inline-block;
	min-width: 26px;
	padding: 2px 4px;
	font-size: 12px;
}

#ed_reply_toolbar input {
	margin: 1px 2px 1px 1px;
}

#quicktags #ed_link,
#ed_reply_toolbar #ed_reply_link {
	text-decoration: underline;
}

#quicktags #ed_del,
#ed_reply_toolbar #ed_reply_del {
	text-decoration: line-through;
}

#quicktags #ed_em,
#ed_reply_toolbar #ed_reply_em {
	font-style: italic;
}

#excerpt, .attachmentlinks {
	margin: 0;
	height: 4em;
	width: 98%;
}

/* post meta postbox */
#postcustomstuff table,
#postcustomstuff input,
#postcustomstuff textarea {
	border-width: 1px;
	border-style: solid;
	-moz-border-radius: 3px;
	-khtml-border-radius: 3px;
	-webkit-border-radius: 3px;
	border-radius: 3px;
}

#postcustomstuff .updatemeta,
#postcustomstuff .deletemeta {
	margin: auto;
}

#postcustomstuff thead th {
	padding: 5px 8px 8px;
}

#postcustom #postcustomstuff .submit,
#pagecustomdiv #postcustomstuff .submit {
	border: 0 none;
	float: none;
	padding: 5px 8px;
}

#side-sortables #postcustom #postcustomstuff .submit,
#side-sortables #pagecustomdiv #postcustomstuff .submit {
	padding: 0 5px;
}

#side-sortables #postcustom #postcustomstuff td.left input,
#side-sortables #pagecustomdiv #postcustomstuff td.left input {
	margin: 3px 3px 0;
}

#side-sortables #postcustom #postcustomstuff #the-list textarea,
#side-sortables #pagecustomdiv #postcustomstuff #the-list textarea {
	height: 85px;
	margin: 3px;
}

#postcustomstuff table {
	margin: 0;
	width: 100%;
	border-width: 1px;
	border-style: solid;
	border-spacing: 0;
}

#postcustomstuff table input,
#postcustomstuff table select,
#postcustomstuff table textarea {
	width: 95%;
	margin: 8px 0 8px 8px;
}

#postcustomstuff th.left,
#postcustomstuff td.left {
	width: 38%;
}

#postcustomstuff .submit input {
	width: auto;
}

#postcustomstuff #newmeta .submit {
	padding: 0 8px;
}

#postcustomstuff table #addmetasub {
	width: auto;
}

#postcustomstuff #newmetaleft {
	vertical-align: top;
}

#postcustomstuff #newmetaleft a {
	padding: 0 10px;
	text-decoration: none;
}

#save {
	width: 15em;
}

#template div {
	margin-right: 190px;
}

* html #template div {
	margin-right: 0;
}

/* A handy div class for hiding controls.
Some browsers will disable them when you
set display: none; */
.zerosize {
	height: 0;
	width: 0;
	margin: 0;
	border: 0;
	padding: 0;
	overflow: hidden;
	position: absolute;
}

* html #themeselect {
	padding: 0 3px;
	height: 22px;
}

#your-profile legend {
	font-family: Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
	font-size: 22px;
}

#your-profile #rich_editing {
	border: none;
}

#howto {
	font-size: 11px;
	margin: 0 5px;
	display: block;
}

#ajax-response.alignleft {
	margin-left: 2em;
}

div.nav {
	height: 2em;
	padding: 7px 10px;
	vertical-align: text-top;
	margin: 5px 0;
}

.nav .button-secondary {
	padding: 2px 4px;
}

a.page-numbers {
	border-bottom-style: solid;
	border-bottom-width: 2px;
	font-weight: bold;
	margin-right: 1px;
	padding: 0 2px;
}

p.pagenav {
	margin: 0;
	display: inline;
}

.pagenav span {
	font-weight: bold;
	margin: 0 6px;
}

.row-title {
	font-size: 12px !important;
	font-weight: bold;
}

.column-comment p {
	margin: 0.6em 0;
}

.column-author img, .column-username img {
	float: left;
	margin-right: 10px;
	margin-top: 3px;
}

.tablenav a.button-secondary {
	display: block;
	margin: 3px 8px 0 0;
}

.tablenav {
	clear: both;
	height: 30px;
	margin: 6px 0 4px;
	vertical-align: middle;
}

.tablenav .tablenav-pages {
	float: right;
	display: block;
	cursor: default;
	height: 30px;
	line-height: 30px;
	font-size: 11px;
}

.tablenav .tablenav-pages a,
.tablenav-pages span.current  {
	text-decoration: none;
	border: none;
	padding: 3px 6px;
	border-width: 1px;
	border-style: solid;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

.tablenav .displaying-num {
	margin-right: 10px;
	font-size: 12px;
	font-family: Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
	font-style: italic;
}

.tablenav .actions {
	padding: 2px 8px 0 0;
}

td.media-icon {
	vertical-align: middle;
	text-align: center;
	width: 80px;
}

td.media-icon img {
	max-width: 80px;
	max-height: 60px;
}

#update-nag {
	line-height: 29px;
	font-size: 12px;
	text-align: center;
}

#update-nag {
	border-width: 1px 0;
	border-style: solid none;
}

.plugins .plugin-update {
	padding: 0;
}

.plugin-update .update-message {
	margin: 0 10px 8px 31px;
	font-weight: bold;
}

#pass-strength-result {
	border-style: solid;
	border-width: 1px;
	float: left;
	margin: 12px 5px 5px 1px;
	padding: 3px 5px;
	text-align: center;
	width: 200px;
}

.row-actions {
	visibility: hidden;
	padding: 2px 0 0;
}

tr:hover .row-actions,
div.comment-item:hover .row-actions {
	visibility: visible;
}

.row-actions-visible {
	padding: 2px 0 0;
	cursor: pointer;
}

/* Admin Header */
#wphead-info {
	margin: 0 0 0 15px;
	padding-right: 15px;
}

#user_info {
	float: right;
	font-size: 12px;
	line-height: 46px;
	height: 46px;
}

#user_info p {
	margin: 0;
	padding: 0;
	line-height: 46px;
}

#wphead {
	height: 46px;
}

#wphead a,
#adminmenu a,
#sidemenu a,
#taglist a,
#catlist a,
#show-settings a {
	text-decoration: none;
}

#header-logo {
	float: left;
	margin: 7px 0 0 15px;
}

#wphead h1 {
	font: normal 22px Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
	padding: 10px 8px 5px;
	margin: 0;
	float: left;
}

#wphead h1.long-title {
	font: normal 18px Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
	padding: 12px 10px 5px;
}

#wphead #site-visit-button {
	background-repeat:repeat-x;
	background-position:0 0;
	-moz-border-radius:3px;
	-webkit-border-radius:3px;
	-khtml-border-radius:3px;
	border-radius:3px;
	cursor:pointer; /* to keep IE happy */
	display:-moz-inline-stack; /* to keep FF2 happy */
	display:inline-block;
	font-size: 50%;
	font-style:normal;
	line-height:17px;
	margin-left:5px;
	padding:0 6px;
	vertical-align:middle;
}

#wphead h1 a:hover {
	text-decoration:none;
}
#wphead h1 a:hover #site-title {
	text-decoration:underline;
}

/* side admin menu */
#adminmenu * {
	-webkit-user-select: none;
	-moz-user-select: none;
	-khtml-user-select: none;
	user-select: none;
}

#adminmenu .wp-submenu {
	display: none;
	list-style: none;
	padding: 0;
	margin: 0;
	position: relative;
	z-index: 2;
	border-width: 1px 0 0;
	border-style: solid none none;
}

#adminmenu .wp-submenu a {
	font: normal 11px/18px "Lucida Grande", Verdana, Arial, "Bitstream Vera Sans", sans-serif;
}

#adminmenu .wp-submenu li.current,
#adminmenu .wp-submenu li.current a,
#adminmenu .wp-submenu li.current a:hover {
	font-weight: bold;
}

#adminmenu a.menu-top,
#adminmenu .wp-submenu-head {
	font: normal 13px/18px Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
}

#adminmenu div.wp-submenu-head {
	display: none;
}

.folded #adminmenu div.wp-submenu-head,
.folded #adminmenu li.wp-has-submenu div.sub-open {
	display: block;
}

.folded #adminmenu a.menu-top,
.folded #adminmenu .wp-submenu,
.folded #adminmenu li.wp-menu-open .wp-submenu,
.folded #adminmenu div.wp-menu-toggle {
	display: none;
}

#adminmenu li.wp-menu-open .wp-submenu,
.no-js #adminmenu .open-if-no-js .wp-submenu {
	display: block;
}

#adminmenu div.wp-menu-image {
	float: left;
	width: 28px;
	height: 28px;
}

#adminmenu li {
	margin: 0;
	padding: 0;
	cursor: pointer;
}

#adminmenu a {
	display: block;
	line-height: 18px;
	padding: 1px 5px 3px;
}

#adminmenu li.menu-top {
	min-height: 26px;
}

#adminmenu a.menu-top {
	line-height: 18px;
	min-width: 10em;
	padding: 5px 5px;
	border-width: 1px 1px 0;
	border-style: solid solid none;
}

#adminmenu .wp-submenu a {
	margin: 0;
	padding-left: 12px;
	border-width: 0 1px 0 0;
	border-style: none solid none none;
}

#adminmenu .menu-top-last ul.wp-submenu {
	border-width: 0 0 1px;
	border-style: none none solid;
}

#adminmenu .wp-submenu li {
	padding: 0;
	margin: 0;
}

.folded #adminmenu li.menu-top {
	width: 28px;
	height: 30px;
	overflow: hidden;
	border-width: 1px 1px 0;
	border-style: solid solid none;
}

#adminmenu .menu-top-first a.menu-top,
.folded #adminmenu li.menu-top-first,
#adminmenu .wp-submenu .wp-submenu-head {
	border-width: 1px 1px 0;
	border-style: solid solid none;
	-moz-border-radius-topleft :6px;
	-moz-border-radius-topright: 6px;
	-webkit-border-top-right-radius: 6px;
	-webkit-border-top-left-radius: 6px;
	-khtml-border-top-right-radius: 6px;
	-khtml-border-top-left-radius: 6px;
	border-top-right-radius: 6px;
	border-top-left-radius: 6px;
}

#adminmenu .menu-top-last a.menu-top,
.folded #adminmenu li.menu-top-last {
	border-width: 1px;
	border-style: solid;
	-moz-border-radius-bottomleft: 6px;
	-moz-border-radius-bottomright: 6px;
	-webkit-border-bottom-right-radius: 6px;
	-webkit-border-bottom-left-radius: 6px;
	-khtml-border-bottom-right-radius: 6px;
	-khtml-border-bottom-left-radius: 6px;
	border-bottom-right-radius: 6px;
	border-bottom-left-radius: 6px;
}

#adminmenu li.wp-menu-open a.menu-top-last {
	border-bottom: 0 none;
	-moz-border-radius-bottomright: 0;
	-moz-border-radius-bottomleft: 0;
	-webkit-border-bottom-right-radius: 0;
	-webkit-border-bottom-left-radius: 0;
	-khtml-border-bottom-right-radius: 0;
	-khtml-border-bottom-left-radius: 0;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0;
}

#adminmenu img.wp-menu-image {
	float: left;
	padding: 8px 6px 0;
	opacity: 0.6;
	filter: alpha(opacity=60);
}

#adminmenu li.menu-top:hover img.wp-menu-image,
#adminmenu li.wp-has-current-submenu img.wp-menu-image {
	opacity: 1;
	filter: alpha(opacity=100);
}

.folded #adminmenu img.wp-menu-image {
	padding: 7px 0 0 6px;
}

#adminmenu li.wp-menu-separator {
	height: 21px;
	padding: 0;
	margin: 0;
}

#adminmenu a.separator {
	cursor: w-resize;
	height: 20px;
	padding: 0;
}

.folded #adminmenu a.separator {
 	cursor: e-resize;
}

#adminmenu .wp-menu-separator-last {
	height: 10px;
	width: 1px;
}

#adminmenu .wp-submenu .wp-submenu-head {
	border-width: 1px;
	border-style: solid;
	padding: 6px 4px 6px 10px;
	cursor: default;
}

.folded #adminmenu .wp-submenu {
	position: absolute;
	margin: -1px 0 0 28px;
	padding: 0 8px 8px;
	z-index: 999;
	border: 0 none;
}

.folded #adminmenu .wp-submenu ul {
	width: 140px;
	border-width: 0 0 1px;
	border-style: none none solid;
}

.folded #adminmenu .wp-submenu li.wp-first-item {
	border-top: 0 none;
}

.folded #adminmenu .wp-submenu a {
	padding-left: 10px;
}

.folded #adminmenu a.wp-has-submenu {
	margin-left: 40px;
}

#adminmenu li.menu-top-last .wp-submenu ul {
	border-width: 0 0 1px;
	border-style: none none solid;
}

#adminmenu .wp-menu-toggle {
	width: 22px;
	clear: right;
	float: right;
	margin: 1px 0 0;
	height: 27px;
	padding: 1px 2px 0 0;
	cursor: default;
}

#adminmenu li.wp-has-current-submenu ul {
	border-bottom-width: 1px;
	border-bottom-style: solid;
}

#adminmenu .wp-menu-image a {
	height: 24px;
}

#adminmenu .wp-menu-image img {
	padding: 6px 0 0 1px;
}

/* end side admin menu */

/* comments/plugins bubble in menu */
#adminmenu #awaiting-mod,
#adminmenu span.update-plugins,
#sidemenu li a span.update-plugins {
	position: absolute;
	font-family: Helvetica, Arial, sans-serif;
	font-size: 7pt;
	font-weight: bold;
	margin-top: 2px;
	margin-left: 2px;
	-moz-border-radius: 7px;
	-khtml-border-radius: 7px;
	-webkit-border-radius: 7px;
	border-radius: 7px;
}

#adminmenu li #awaiting-mod span,
#adminmenu li span.update-plugins span,
#sidemenu li a span.update-plugins span {
	float: left;
	display: block;
	height: 1.6em;
	line-height: 1.6em;
	padding: 0 6px;
}

#adminmenu li span.count-0,
#sidemenu li a .count-0 {
	display: none;
}
/* end menu stuff */

/* comments bubble */
.post-com-count-wrapper {
	min-width: 22px;
	font-family: Helvetica, Arial, sans-serif;
}

.post-com-count {
	height: 1.3em;
	line-height: 1.1em;
	display: block;
	text-decoration: none;
	padding: 0 0 6px;
	cursor: pointer;
	background-position: center -80px;
	background-repeat: no-repeat;
}

.post-com-count span {
	font-size: 9px;
	font-weight: bold;
	height: 1.7em;
	line-height: 1.70em;
	min-width: 0.7em;
	padding: 0 6px;
	display: inline-block;
	cursor: pointer;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

strong .post-com-count {
	background-position: center -55px;
}

.post-com-count:hover {
	background-position: center -3px;
}

.column-response .post-com-count {
	float: left;
	margin-right: 5px;
	text-align: center;
}

.response-links {
	float: left;
}

#the-comment-list .attachment-80x60 {
	padding: 4px 8px;
}

/* Admin Footer */
#footer {
	margin-top: -45px;
}

#footer,
#footer a {
	font-size: 12px;
	font-family: Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
	font-style: italic;
}

#footer p {
	margin: 0;
	padding: 15px;
	line-height: 15px;
}

#footer a {
	text-decoration: none;
}

#footer a:hover {
	text-decoration: underline;
}

/* Tables used on comment.php and option/setting pages */

.form-table {
	border-collapse: collapse;
	margin-top: 0.5em;
	width: 100%;
	margin-bottom: -8px;
	clear: both;
}

.form-table td,
#wpbody-content .describe td {
	margin-bottom: 9px;
	padding: 4px 10px 12px;
	line-height: 20px;
	font-size: 11px;
}

.form-table th,
.form-wrap label {
	font-weight: normal;
	text-shadow: rgba(255,255,255,1) 0 1px 0;
}

.form-table th,
#wpbody-content .describe th {
	vertical-align: top;
	text-align: left;
	padding: 10px;
	width: 200px;
}

.form-table th.th-full {
	width: auto;
}

.form-table input,
.form-table textarea,
#wpbody-content .describe input,
#wpbody-content .describe textarea {
	border-width: 1px;
	border-style: solid;
}

.form-table div.color-option {
	display: block;
	clear: both;
	margin-top: 12px;
}

.form-table input.tog {
	margin-top: 2px;
	margin-right: 2px;
	float: left;
}

.form-table table.color-palette {
	vertical-align: bottom;
	float: left;
	margin: -12px 3px 11px;
}

.form-table .color-palette td {
	border-width: 1px 1px 0;
	border-style: solid solid none;
	height: 10px;
	line-height: 20px;
	width: 10px;
}

textarea.large-text {
	width: 99%;
}

.form-table input.regular-text,
#adduser .form-field input {
	width: 25em;
}

.form-table input.small-text {
	width: 50px;
}

#profile-page .form-table textarea {
	width: 500px;
	margin-bottom: 6px;
}

#profile-page .form-table #rich_editing {
	margin-right: 5px
}

.form-table .pre {
	padding: 8px;
	margin: 0;
}

.pre {
	/* http://www.longren.org/2006/09/27/wrapping-text-inside-pre-tags/ */
	white-space: pre-wrap; /* css-3 */
	white-space: -moz-pre-wrap !important; /* Mozilla, since 1999 */
	white-space: -pre-wrap; /* Opera 4-6 */
	white-space: -o-pre-wrap; /* Opera 7 */
	word-wrap: break-word; /* Internet Explorer 5.5+ */
}

table.form-table td .updated {
	font-size: 13px;
}

/* divs for cats and tags pages */

.form-wrap {
	margin: 10px 0;
	width: 97%;
}

.form-wrap p,
.form-wrap label {
	font-size: 11px;
}

.form-wrap label {
	display: block;
	padding: 2px;
	font-size: 12px;
}

.form-field input,
.form-field textarea {
	border-style: solid;
	border-width: 1px;
	width: 95%;
}

p.description,
.form-wrap p {
	margin: 2px 0 5px;
}

p.help,
p.description,
span.description,
.form-wrap p {
	font-size: 12px;
	font-style: italic;
	font-family: "Lucida Grande", Verdana, Arial, "Bitstream Vera Sans", sans-serif;
}

.form-wrap .form-field {
	margin: 0 0 10px;
	padding: 8px;
}

.col-wrap h3 {
	margin: 12px 0;
	font-size: 1.1em;
}

.col-wrap p.submit {
	margin-top: -10px;
}

.tagcloud {
	width: 97%;
	margin: 0 0 40px;
	text-align: justify;
}

.tagcloud h3 {
	margin: 2px 0 12px;
}

/* Post Screen */
#post-body #normal-sortables {
	min-height: 50px;
}

#post-body #advanced-sortables {
	min-height: 20px;
}

.postbox {
	position: relative;
	min-width: 255px;
	width: 99.5%;
}

#trackback_url {
	width: 99%;
}

#normal-sortables .postbox .submit {
	background: transparent none;
	border: 0 none;
	float: right;
	padding: 0 12px;
	margin: 0;
}

#normal-sortables .postbox #replyrow .submit {
	float: none;
	margin: 0;
	padding: 3px 7px;
}

#side-sortables .submitbox .submit input,
#side-sortables .submitbox .submit .preview,
#side-sortables .submitbox .submit a.preview:hover {
	border: 0 none;
}

#side-sortables .inside-submitbox .insidebox,
.stuffbox .insidebox {
	margin: 11px 0;
}

#side-sortables .comments-box,
#normal-sortables .comments-box {
	border: 0 none;
}

#side-sortables .comments-box thead th,
#normal-sortables .comments-box thead th {
	background: transparent;
	padding: 0 7px 4px;
	font-style: italic;
}

#commentsdiv img.waiting {
	padding-left: 5px;
	vertical-align: middle;
}

#post-body .tagsdiv #newtag {
	margin-right: 5px;
	width: 16em;
}

#side-sortables input#post_password {
	width: 94%
}

#side-sortables .tagsdiv #newtag {
	width: 68%;
}

#post-status-info {
	border-width: 0 1px 1px;
	border-style: none solid solid;
	width: 100%;
	-moz-border-radius: 0 0 6px 6px;
	-webkit-border-bottom-left-radius: 6px;
	-webkit-border-bottom-right-radius: 6px;
	-khtml-border-bottom-left-radius: 6px;
	-khtml-border-bottom-right-radius: 6px;
	border-bottom-left-radius: 6px;
	border-bottom-right-radius: 6px;
}

#post-status-info td {
	font-size: 11px;
}

.autosave-info {
	padding: 2px 15px 2px 2px;
	text-align: right;
}

#editorcontent #post-status-info {
	border: none;
}

#post-body .wp_themeSkin .mceStatusbar a.mceResize {
	display: block;
	background: transparent url(images/resize.gif) no-repeat scroll right bottom;
	width: 12px;
	cursor: se-resize;
	margin: 0 2px;
	position: relative;
	top: 22px;
}


#pagesubmitdiv div.inside,
#linksubmitdiv div.inside,
 div.inside {
	padding: 0;
	margin: 0;
}

#comment-status-radio p {
	margin: 3px 0 5px;
}

#comment-status-radio input {
	margin: 2px 3px 5px 0;
	vertical-align: middle;
}

#comment-status-radio label {
	padding: 5px 0;
}

.tagchecklist {
	margin-left: 10px;
	font-size: 12px;
	overflow: auto;
}

.tagchecklist strong {
	margin-left: -8px;
	position: absolute;
}

.tagchecklist span {
	margin-right: 25px;
	display: block;
	float: left;
	font-size: 11px;
	line-height: 1.8em;
	white-space: nowrap;
	cursor: default;
}

.tagchecklist span a {
	margin: 6px 0pt 0pt -9px;
	cursor: pointer;
	width: 10px;
	height: 10px;
	display: block;
	float: left;
	text-indent: -9999px;
	overflow: hidden;
	position: absolute;
}

.howto {
	font-style: italic;
	display: block;
	font-family: "Lucida Grande", Verdana, Arial, "Bitstream Vera Sans", sans-serif;
}

.ac_results {
	padding: 0;
	margin: 0;
	list-style: none;
	position: absolute;
	z-index: 10000;
	display: none;
	border-width: 1px;
	border-style: solid;
}

.ac_results li {
	padding: 2px 5px;
	white-space: nowrap;
	text-align: left;
}

.ac_over {
	cursor: pointer;
}

.ac_match {
	text-decoration: underline;
}

#poststuff h2 {
	margin-top: 20px;
	font-size: 1.5em;
	margin-bottom: 15px;
	padding: 0 0 3px;
	clear: left;
}

.widget .widget-top,
.postbox h3 {
	cursor: move;
	-webkit-user-select: none;
	-moz-user-select: none;
	-khtml-user-select: none;
	user-select: none;
}

.postbox .hndle span {
	padding: 6px 0;
}

.postbox .hndle {
	cursor: move;
}

.hndle a {
	font-size: 11px;
	font-weight: normal;
}

#dashboard-widgets .meta-box-sortables {
	margin: 0 5px;
}

.postbox .handlediv {
	float: right;
	width: 23px;
	height: 26px;
}

.sortable-placeholder {
	border-width: 1px;
	border-style: dashed;
	margin-bottom: 20px;
}

#poststuff h3,
.metabox-holder h3 {
	font-size: 12px;
	font-weight: bold;
	padding: 7px 9px;
	margin: 0;
	line-height: 1;
}

.widget,
.postbox,
.stuffbox {
	margin-bottom: 20px;
	border-width: 1px;
	border-style: solid;
	line-height: 1;
	-moz-border-radius: 6px;
	-khtml-border-radius: 6px;
	-webkit-border-radius: 6px;
	border-radius: 6px;
}

.widget .widget-top,
.postbox h3,
.postbox h3,
.stuffbox h3 {
	-moz-border-radius: 6px 6px 0 0;
	-webkit-border-top-right-radius: 6px;
	-webkit-border-top-left-radius: 6px;
	-khtml-border-top-right-radius: 6px;
	-khtml-border-top-left-radius: 6px;
	border-top-right-radius: 6px;
	border-top-left-radius: 6px;
}

.postbox.closed h3 {
	-moz-border-radius-bottomleft:4px;
	-webkit-border-bottom-left-radius: 4px;
	-khtml-border-bottom-left-radius: 4px;
	border-bottom-left-radius: 4px;
	-moz-border-radius-bottomright:4px;
	-webkit-border-bottom-right-radius: 4px;
	-khtml-border-bottom-right-radius: 4px;
	border-bottom-right-radius: 4px;
}

.postbox table.form-table {
	margin-bottom: 0;
}

.postbox input[type="text"],
.postbox textarea,
.stuffbox input[type="text"],
.stuffbox textarea {
	border-width: 1px;
	border-style: solid;
}

#poststuff .inside,
#poststuff .inside p {
	font-size: 11px;
	margin: 6px;
}

#poststuff .inside .submitbox p {
	margin: 1em 0;
}

#post-visibility-select {
	line-height: 1.5em;
	margin-top: 3px;
}

#poststuff #submitdiv .inside {
	margin: 0;
}

#titlediv, #poststuff .postarea {
	margin-bottom: 20px;
}

#titlediv {
	margin-bottom: 20px;
}
#titlediv label { cursor: text; }

#titlediv div.inside {
	margin: 0;
}

#poststuff #titlewrap {
	border: 0;
	padding: 0;

}

#titlediv #title {
	padding: 3px 4px;
	border-width: 1px;
	border-style: solid;
	-moz-border-radius: 6px;
	-khtml-border-radius: 6px;
	-webkit-border-radius: 6px;
	border-radius: 6px;
	font-size: 1.7em;
	width: 100%;
	outline: none;
}

#poststuff .inside-submitbox,
#side-sortables .inside-submitbox {
	margin: 0 3px;
	font-size: 11px;
}

input#link_description,
input#link_url {
	width: 98%;
}

#pending {
	background: 0 none;
	border: 0 none;
	padding: 0;
	font-size: 11px;
	margin-top: -1px;
}

#edit-slug-box {
	height: 1em;
	margin-top: 8px;
	padding: 0 7px;
}

#editable-post-name-full {
	display: none;
}

#editable-post-name input {
	width: 16em;
}

.postarea h3 label {
	float: left;
}

.postarea #add-media-button {
	float: right;
	margin: 7px 0pt 0pt;
	position: relative;
	right: 10px;
}

#poststuff #editor-toolbar {
	height: 30px;
}

.wp_themeSkin tr.mceFirst td.mceToolbar {
	border-width: 0 0 1px;
	border-style: none none solid;
}

#edButtonPreview,
#edButtonHTML {
	height: 18px;
	margin: 5px 5px 0 0;
	padding: 4px 5px 2px;
	float: right;
	cursor: pointer;
	border-width: 1px;
	border-style: solid;
	-moz-border-radius: 3px 3px 0 0;
	-webkit-border-top-right-radius: 3px;
	-webkit-border-top-left-radius: 3px;
	-khtml-border-top-right-radius: 3px;
	-khtml-border-top-left-radius: 3px;
	border-top-right-radius: 3px;
	border-top-left-radius: 3px;
}

.js .theEditor {
	color: white;
}

#poststuff #edButtonHTML {
	margin-right: 15px;
}

#media-buttons {
	cursor: default;
	padding: 8px 8px 0;
}

#media-buttons a {
	cursor: pointer;
	padding: 0 0 5px 10px;
}

#media-buttons img {
	vertical-align: middle;
}

.submitbox .submit {
	text-align: left;
	padding: 12px 10px 10px;
	font-size: 11px;
}

.submitbox .submitdelete {
	border-bottom-width: 1px;
	border-bottom-style: solid;
	text-decoration: none;
	padding: 1px 2px;
}

.inside-submitbox #post_status {
	margin: 2px 0 2px -2px;
}

.submitbox .submit a:hover {
	border-bottom-width: 1px;
	border-bottom-style: solid;
}

.submitbox .submit input {
	margin-bottom: 8px;
	margin-right: 4px;
	padding: 6px;
}

#post-status-select {
	line-height: 2.5em;
	margin-top: 3px;
}

/* Categories */

#category-adder {
	margin-left: 120px;
	padding: 4px 0;
}

#category-adder h4 {
	margin: 0 0 8px;
}

#side-sortables #category-adder {
	margin: 0;
}

#post-body #category-add input, #category-add select {
	width: 30%;
}

#side-sortables #category-add input {
	width: 94%;
}

#side-sortables #category-add select {
	width: 100%;
}

#category-add input#category-add-sumbit {
	width: auto;
}

#post-body ul#category-tabs {
	float: left;
	width: 120px;
	text-align: right;
	/* Negative margin for the sake of those without JS: all tabs display */
	margin: 0 -120px 0 5px;
	padding: 0;
}

#post-body ul#category-tabs li {
	padding: 8px;
}

#post-body ul#category-tabs li.tabs {
	-moz-border-radius: 3px 0 0 3px;
	-webkit-border-top-left-radius: 3px;
	-webkit-border-bottom-left-radius: 3px;
	-khtml-border-top-left-radius: 3px;
	-khtml-border-bottom-left-radius: 3px;
	border-top-left-radius: 3px;
	border-bottom-left-radius: 3px;
}

#post-body ul#category-tabs li.tabs a {
	font-weight: bold;
	text-decoration: none;
}

#categorydiv div.tabs-panel,
#linkcategorydiv div.tabs-panel {
	height: 150px;
	overflow: auto;
	padding: 0.5em 0.9em;
	border-style: solid;
	border-width: 1px;
}

#post-body #categorydiv div.tabs-panel,
#post-body #linkcategorydiv div.tabs-panel {
	margin: 0 5px 0 125px;
}

#side-sortables #category-tabs li {
	display: inline;
	padding-right: 8px;
}

#side-sortables #category-tabs a {
	text-decoration: none;
}

#side-sortables #category-tabs {
	margin-bottom: 3px;
}

#categorydiv ul,
#linkcategorydiv ul {
	list-style: none;
	padding: 0;
	margin: 0;
}

#categorydiv ul.categorychecklist ul,
#linkcategorydiv ul.categorychecklist ul {
	margin-left: 18px;
}

ul.categorychecklist li {
	margin: 0;
	padding: 0;
	line-height: 19px;
}

#category-adder h4 {
	margin-top: 4px;
	margin-bottom: 0px;
}

#categorydiv .tabs-panel {
	border-width: 3px;
	border-style: solid; 
}

ul#category-tabs {
	margin-top: 12px;
}

ul#category-tabs li.tabs {
	border-style: solid solid none;
	border-width: 1px 1px 0;
}

#post-body #category-tabs li.tabs {
	border-style: solid none solid solid;
	border-width: 1px 0 1px 1px;
	margin-right: -1px;
}

ul#category-tabs li {
	padding: 5px 8px;
	-moz-border-radius: 3px 3px 0 0;
	-webkit-border-top-left-radius: 3px;
	-webkit-border-top-right-radius: 3px;
	-khtml-border-top-left-radius: 3px;
	-khtml-border-top-right-radius: 3px;
	border-top-left-radius: 3px;
	border-top-right-radius: 3px;
}

/* positioning etc. */

form#tags-filter {
	position: relative;
}

p.search-box {
	float: right;
	margin: -5px 0 0;
}

.screen-per-page {
	width: 3em;
}

#posts-filter fieldset {
	float: left;
	margin: 0 1.5ex 1em 0;
	padding: 0;
}

#posts-filter fieldset legend {
	padding: 0 0 .2em 1px;
}

/* Edit posts */

td.post-title strong, td.plugin-title strong {
	display: block;
	margin-bottom: .2em;
}

td.post-title p, td.plugin-title p {
	margin: 6px 0;
}

td.plugin-title {
	white-space: nowrap;
}

/* Global classes */

.wp-hidden-children .wp-hidden-child,
.ui-tabs-hide,
#codepress-off {
	display: none;
}

.commentlist .avatar {
	vertical-align: text-top;
}

.defaultavatarpicker .avatar {
	margin: 2px 0;
	vertical-align: middle;
}

body.wp-admin {
	min-width: 785px;
}

.view-switch {
	float: right;
	margin: 6px 8px 0;
}

.view-switch a {
	text-decoration: none;
}

.filter {
	float: left;
	margin: -5px 0 0 10px;
}

.filter .subsubsub {
	margin-left: -10px;
	margin-top: 13px;
}

#the-comment-list td.comment p.comment-author {
	margin-top: 0;
	margin-left: 0;
}

#the-comment-list p.comment-author img {
	float: left;
	margin-right: 8px;
}

#the-comment-list p.comment-author strong a {
	border: none;
}

#the-comment-list td {
	vertical-align: top;
}

#the-comment-list td.comment {
	word-wrap: break-word;
}

#the-comment-list .check-column {
	padding-top: 8px;
}

#templateside ul li a {
	text-decoration: none;
}

.indicator-hint {
	padding-top: 8px;
}

#display_name {
	width: 15em;
}

.tablenav .delete {
	margin-right: 20px;
}

td.action-links,
th.action-links {
	text-align: right;
}

/* Diff */

table.diff {
	width: 100%;
}

table.diff col.content {
	width: 50%;
}

table.diff tr {
	background-color: transparent;
}

table.diff td, table.diff th {
	padding: .5em;
	font-family: Consolas, Monaco, Courier, monospace;
	border: none;
}

table.diff .diff-deletedline del, table.diff .diff-addedline ins {
	text-decoration: none;
}

#wp-word-count {
	display: block;
	padding: 2px 7px;
}

fieldset {
	border: 0;
	padding: 0;
	margin: 0;
}

.tool-box {
	margin: 15px 0 35px;
}

.tool-box .buttons {
	margin: 15px 0;
}

.tool-box .title {
	margin: 8px 0;
	font: 18px/24px Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
}

.pressthis a {
	font-size: 1.2em;
}

#wp_editbtns,
#wp_gallerybtns {
	padding: 2px;
	position: absolute;
	display: none;
	z-index: 999998;
}

#wp_editimgbtn,
#wp_delimgbtn,
#wp_editgallery,
#wp_delgallery {
	margin: 2px;
	padding: 2px;
	border-width: 1px;
	border-style: solid;
	-moz-border-radius: 3px;
	-khtml-border-radius: 3px;
	-webkit-border-radius: 3px;
	border-radius: 3px;
}

.settings-toggle {
	text-align: right;
	margin: 5px 7px 15px 0;
	font-size: 12px;
}

.settings-toggle h3 {
	margin: 0;
}

#timestampdiv select {
	height: 20px;
	line-height: 20px;
	padding: 0;
}

#jj, #hh, #mn {
	width: 2em;
	padding: 1px;
	font-size: 12px;
}

#aa {
	width: 3.4em;
	padding: 1px;
	font-size: 12px;
}

.curtime #timestamp {
	background-repeat: no-repeat;
	background-position: left top;
	padding-left: 18px;
}

#timestampdiv {
	padding-top: 5px;
	line-height: 23px;
}

#timestampdiv p {
	margin: 8px 0 6px;
}

#timestampdiv input {
	border-width: 1px;
	border-style: solid;
}

/* media popup 0819 */
#sidemenu {
	margin: -30px 15px 0 315px;
	list-style: none;
	position: relative;
	float: right;
	padding-left: 10px;
	font-size: 12px;
}

#sidemenu a {
	padding: 0 7px;
	display: block;
	float: left;
	line-height: 28px;
	border-top-width: 1px;
	border-top-style: solid;
	border-bottom-width: 1px;
	border-bottom-style: solid;
}

#sidemenu li {
	display: inline;
	line-height: 200%;
	list-style: none;
	text-align: center;
	white-space: nowrap;
	margin: 0;
	padding: 0;
}

#sidemenu a.current {
	font-weight: normal;
	padding-left: 6px;
	padding-right: 6px;
	-moz-border-radius: 4px 4px 0 0;
	-webkit-border-top-left-radius: 4px;
	-webkit-border-top-right-radius: 4px;
	-khtml-border-top-left-radius: 4px;
	-khtml-border-top-right-radius: 4px;
	border-top-left-radius: 4px;
	border-top-right-radius: 4px;
	border-width: 1px;
	border-style: solid;
}

#sidemenu {
	margin: -30px 15px 0 315px;
	list-style: none;
	position: relative;
	float: right;
	padding-left: 10px;
	font-size: 12px;
}

#sidemenu a {
	padding: 0 7px;
	display: block;
	float: left;
	line-height: 28px;
	border-top-width: 1px;
	border-top-style: solid;
	border-bottom-width: 1px;
	border-bottom-style: solid;
}

#sidemenu li a .count-0 {
	display: none;
}

/* reply to comments */
#replyrow {
	font-size: 11px;
}

#replyrow input {
	border-width: 1px;
	border-style: solid;
}

#replyrow td {
	padding: 2px;
}

#replyrow #editorcontainer {
	border: 0 none;
}

#replysubmit {
	margin: 0;
	padding: 3px 7px;
}

#replysubmit img.waiting,
.inline-edit-save img.waiting,
#commentstatusdiv img.waiting {
	padding: 0 10px;
	vertical-align: top;
}

#replysubmit .button {
	margin-right: 5px;
}

#replyrow #editor-toolbar {
	display: none;
}

#replyhead {
	font-size: 12px;
	font-weight: bold;
	padding: 2px 10px 4px;
}

#edithead .inside {
	float: left;
	padding: 3px 0 2px 5px;
	margin: 0;
	text-align: center;
	font-size: 11px;
}

#edithead .inside input {
	width: 180px;
	font-size: 11px;
}

#edithead label {
	padding: 2px 0;
}

#replycontainer {
	padding: 5px;
	border: 0 none;
	height: 120px;
	overflow: hidden;
	position: relative;
}

#replycontent {
	resize: none;
	margin: 0;
	width: 100%;
	height: 100%;
	padding: 0;
	line-height: 150%;
	border: 0 none;
	outline: none;
	font-size: 12px;
}

#replyrow #ed_reply_toolbar {
	margin: 0;
	padding: 2px 3px;
}

/* show/hide settings */
#screen-meta {
	position: relative;
	clear: both;
}

#screen-meta-links {
	margin: 0 9px 0 0;
}

#screen-meta .screen-reader-text {
	visibility: hidden;
}

#screen-options-link-wrap,
#contextual-help-link-wrap {
	float: right;
	background: transparent url( images/screen-options-left.gif ) no-repeat 0 0;
	font-family: "Lucida Grande", Verdana, Arial, "Bitstream Vera Sans", sans-serif;
	height: 22px;
	padding: 0;
	margin: 0 6px 0 0;
}

#screen-meta a.show-settings {
	text-decoration: none;
	z-index: 1;
	padding: 0 16px 0 6px;
	height: 22px;
	line-height: 22px;
	font-size: 10px;
	display: block;
	background-repeat: no-repeat;
	background-position: right bottom;
}

#screen-meta a.show-settings {
	background-image: url( images/screen-options-right.gif );
}

#screen-meta a.show-settings:hover {
	text-decoration: none;
}

#screen-options-wrap h5,
#contextual-help-wrap h5 {
	margin: 8px 0;
	font-size: 13px;
}

#screen-options-wrap,
#contextual-help-wrap {
	border-style: none solid solid;
	border-top: 0 none;
	border-width: 0 1px 1px;
	margin: 0 15px;
	padding: 8px 12px 12px;
	-moz-border-radius: 0 0 0 4px;
	-webkit-border-bottom-left-radius: 4px;
	-khtml-border-bottom-left-radius: 4px;
	border-bottom-left-radius: 4px;
}

.metabox-prefs label {
	padding-right: 15px;
	white-space: nowrap;
	line-height: 30px;
}

.metabox-prefs label input {
	margin: 0 5px 0 2px;
}

.metabox-prefs label a {
	display: none;
}

/* Inline Editor
	.quick-edit* is for Quick Edit
	.bulk-edit* is for Bulk Edit
	.inline-edit* is for everything
*/
/*	Layout */
tr.inline-edit-row td {
	padding: 0 0.5em;
}

#wpbody-content .inline-edit-row fieldset {
	font-size: 12px;
	float: left;
	margin: 0;
	padding: 0;
	width: 100%;
}

#wpbody-content .inline-edit-row fieldset .inline-edit-col {
	padding: 0 0.5em;
}

#wpbody-content .quick-edit-row-page fieldset.inline-edit-col-right .inline-edit-col {
	border-width: 0 0 0 1px;
	border-style: none none none solid;
}

#wpbody-content .quick-edit-row-post .inline-edit-col-left {
	width: 40%;
}

#wpbody-content .quick-edit-row-post .inline-edit-col-right {
	width: 39%;
}

#wpbody-content .inline-edit-row-post .inline-edit-col-center {
	width: 20%;
}

#wpbody-content .quick-edit-row-page .inline-edit-col-left {
	width: 50%;
}

#wpbody-content .quick-edit-row-page .inline-edit-col-right,
#wpbody-content .bulk-edit-row-post .inline-edit-col-right {
	width: 49%;
}

#wpbody-content .bulk-edit-row .inline-edit-col-left {
	width: 30%;
}

#wpbody-content .bulk-edit-row-page .inline-edit-col-right {
	width: 69%;
}

#wpbody-content .bulk-edit-row .inline-edit-col-bottom {
	float: right;
	width: 69%;
}

#wpbody-content .inline-edit-row-page .inline-edit-col-right,
#owpbody-content .bulk-edit-row-post .inline-edit-col-right {
	margin-top: 27px;
}

.inline-edit-row fieldset .inline-edit-group {
	clear: both;
}

.inline-edit-row fieldset .inline-edit-group:after {
	content: ".";
	display: block;
	height: 0;
	clear: both;
	visibility: hidden;
}

.inline-edit-row p.submit {
	clear: both;
	padding: 0.5em;
	margin: 0.5em 0 0;
}

.inline-edit-row span.error {
	line-height: 22px;
	margin: 0 15px;
	padding: 3px 5px;
}

/*	Positioning */
.inline-edit-row h4 {
	margin: .2em 0;
	padding: 0;
	line-height: 23px;
}
.inline-edit-row fieldset span.title,
.inline-edit-row fieldset span.checkbox-title {
	margin: 0;
	padding: 0;
	line-height: 27px;
}

.inline-edit-row fieldset label,
.inline-edit-row fieldset span.inline-edit-categories-label {
	display: block;
	margin: .2em 0;
}

.inline-edit-row fieldset label.inline-edit-tags {
	margin-top: 0;
}

.inline-edit-row fieldset label.inline-edit-tags span.title {
	margin: .2em 0;
}

.inline-edit-row fieldset label span.title {
	display: block;
	float: left;
	width: 5em;
}

.inline-edit-row fieldset label span.input-text-wrap {
	display: block;
	margin-left: 5em;
}

.quick-edit-row-post fieldset.inline-edit-col-right label span.title {
	width: auto;
	padding-right: 0.5em;
}

.inline-edit-row .input-text-wrap input[type=text] {
	width: 100%;
}

.inline-edit-row fieldset label input[type=checkbox] {
	vertical-align: text-bottom;
}

.inline-edit-row fieldset label textarea {
	width: 100%;
	height: 4em;
}

#wpbody-content .bulk-edit-row fieldset .inline-edit-group label {
	max-width: 50%;
}

#wpbody-content .quick-edit-row fieldset .inline-edit-group label.alignleft:first-child {
	margin-right: 0.5em
}

/*	Styling */
.inline-edit-row h4 {
	text-transform: uppercase;
}

.inline-edit-row fieldset span.title,
.inline-edit-row fieldset span.checkbox-title {
	font-family: Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
	font-style: italic;
	line-height: 1.8em;
}

/*	Specific Elements */
.inline-edit-row fieldset input[type="text"],
.inline-edit-row fieldset textarea {
	border-style: solid;
	border-width: 1px;
}

.inline-edit-row fieldset .inline-edit-date {
	float: left;
}

.inline-edit-row fieldset input[name=jj],
.inline-edit-row fieldset input[name=hh],
.inline-edit-row fieldset input[name=mn] {
	font-size: 12px;
	width: 2.1em;
}

.inline-edit-row fieldset input[name=aa] {
	font-size: 12px;
	width: 3.5em;
}

.inline-edit-row fieldset label input.inline-edit-password-input {
	width: 8em;
}

.inline-edit-row .catshow,
.inline-edit-row .cathide {
	cursor: pointer;
}

ul.cat-checklist {
	height: 12em;
	border-style: solid;
	border-width: 1px;
	overflow-y: scroll;
	padding: 0 5px;
	margin: 0;
}

#bulk-titles {
	display: block;
	height: 12em;
	border-style: solid;
	border-width: 1px;
	overflow-y: scroll;
	padding: 0 5px;
	margin: 0 0 5px;
}

.inline-edit-row fieldset ul.cat-checklist li,
.inline-edit-row fieldset ul.cat-checklist input {
	margin: 0;
}

.inline-edit-row fieldset ul.cat-checklist label,
.inline-edit-row .catshow,
.inline-edit-row .cathide,
.inline-edit-row #bulk-titles div {
	font-family: "Lucida Grande", Verdana, Arial, "Bitstream Vera Sans", sans-serif;
	font-style: normal;
	font-size: 11px;
}

table .inline-edit-row fieldset ul.cat-hover {
	height: auto;
	max-height: 30em;
	overflow-y: auto;
	position: absolute;
}

.inline-edit-row fieldset label input.inline-edit-menu-order-input {
	width: 3em;
}

.inline-edit-row fieldset label input.inline-edit-slug-input {
	width: 75%;
}

.quick-edit-row-post fieldset label.inline-edit-status {
	float: left;
}

#bulk-titles {
	line-height: 140%;
}
#bulk-titles div {
	margin: 0.2em 0.3em;
}

#bulk-titles div a {
	cursor: pointer;
	display: block;
	float: left;
	height: 10px;
	margin: 3px 3px 0 -2px;
	overflow: hidden;
	position: relative;
	text-indent: -9999px;
	width: 10px;
}

/* Media library */
#wpbody-content #media-items .describe {
	border-collapse: collapse;
	width: 100%;
	border-top-style: solid;
	border-top-width: 1px;
	clear: both;
	cursor: default;
	padding: 5px;
	width: 100%;
}

#wpbody-content .describe .media-item-info tr {
	background-color: transparent;
}

#wpbody-content .filename {
	padding: 0 10px;
}

#wpbody-content .media-item .thumbnail {
	max-height: 128px;
	max-width: 128px;
}

#wpbody-content .media-upload-form label {
	display: block;
	font-size: 13px;
	margin: 0.5em;
}

abbr.required {
	border: medium none;
	text-decoration: none;
}

#wpbody-content .describe input[type="text"],
#wpbody-content .describe textarea {
	width: 460px;
}

#wpbody-content .describe p.help {
	margin: 0;
	padding: 0 0 0 5px;
}

.describe-toggle-on, .describe-toggle-off {
	display: block;
	line-height: 36px;
	float: right;
	margin-right: 20px;
}

.describe-toggle-off {
	display: none;
}

#wpbody-content .media-item {
	border-bottom-style: solid;
	border-bottom-width: 1px;
	min-height: 36px;
	position: relative;
	width: 100%;
}

#wpbody-content #media-items {
	border-style: solid solid none;
	border-width: 1px;
	width: 670px;
}

#wpbody-content #media-items .filename {
	line-height: 36px;
	overflow: hidden;
}

.media-item .pinkynail {
	float: left;
	height: 32px;
	margin: 2px;
	max-width: 40px;
	max-height: 40px;
}

.media-item .startopen,
.media-item .startclosed {
	display: none;
}

.media-item .original {
	position: relative;
	height: 34px;
	text-align: center;
}

.media-item .percent {
	font-weight: bold;
}

.crunching {
	display: block;
	line-height: 32px;
	text-align: right;
	margin-right: 5px;
}

button.dismiss {
	position: absolute;
	top: 7px;
	right: 5px;
	z-index: 4;
	width: 8em;
}

.file-error {
	float: left;
	font-weight: bold;
	padding: 10px;
}

.progress {
	position: relative;
	margin-bottom: -36px;
	height: 36px;
}

.bar {
	width: 0;
	height: 100%;
	border-right-width: 3px;
	border-right-style: solid;
}

#media-items a.delete,
#media-items a.del-link {
	padding: 1px 4px 2px;
}


/* find posts */
.find-box {
	width: 500px;
	height: 300px;
	overflow: hidden;
	padding: 33px 5px 40px;
	position: absolute;
	z-index: 1000;
}

.find-box-head {
	cursor: move;
	font-weight: bold;
	height: 2em;
	line-height: 2em;
	padding: 1px 12px;
	position: absolute;
	top: 5px;
	width: 100%;
}

.find-box-inside {
	overflow: auto;
	width: 100%;
	height: 100%;
}

.find-box-search {
	padding: 12px;
	border-width: 1px;
	border-style: none none solid;
}

#find-posts-response {
	margin: 8px 0;
	padding: 0 1px;
}

#find-posts-response table {
	width: 100%;
}

#find-posts-response .found-radio {
	padding: 5px 0 0 8px;
	width: 15px;
}

.find-box-buttons {
	width: 480px;
	margin: 8px;
}

.find-box-search label {
	padding-right: 6px;
}

.find-box #resize-se {
	position: absolute;
	right: 1px;
	bottom: 1px;
}

/* favorite-actions */
#favorite-actions {
	float: right;
	margin: 11px 12px 0;
	min-width: 130px;
	position: relative;
}

#favorite-first {
	-moz-border-radius: 12px;
	-khtml-border-radius: 12px;
	-webkit-border-radius: 12px;
	border-radius: 12px;
	line-height: 15px;
	padding: 3px 30px 4px 12px;
	border-width: 1px;
	border-style: solid;
}

#favorite-inside {
	margin: 0 0 0 0px;
	padding: 0 1px 6px 1px;
	border-width: 1px;
	border-style: solid;
	position: absolute;
	z-index: 11;
	display: none;
	-moz-border-radius: 0 0 12px 12px;
	-webkit-border-bottom-right-radius: 12px;
	-webkit-border-bottom-left-radius: 12px;
	-khtml-border-bottom-right-radius: 12px;
	-khtml-border-bottom-left-radius: 12px;
	border-bottom-right-radius: 12px;
	border-bottom-left-radius: 12px;
}

#favorite-actions a {
	display: block;
	text-decoration: none;
	font-size: 11px;
}

#favorite-inside a {
	padding: 3px 5px 3px 10px;
}

#favorite-toggle {
	height: 22px;
	position: absolute;
	right: 0;
	top: 1px;
	width: 28px;
}

#favorite-actions .slide-down {
	-moz-border-radius: 12px 12px 0 0;
	-webkit-border-bottom-right-radius: 0;
	-webkit-border-bottom-left-radius: 0;
	-khtml-border-bottom-right-radius: 0;
	-khtml-border-bottom-left-radius: 0;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0;
	border-bottom-width: 1px;
	border-bottom-style: solid;
}

#utc-time, #local-time {
	padding-left: 25px;
	font-style: italic;
	font-family: "Lucida Grande", Verdana, Arial, "Bitstream Vera Sans", sans-serif;
}

ul#dismissed-updates {
	display: none;
}
form.upgrade {
	margin-top: 8px;
}

form.upgrade .hint {
	font-style: italic;
	font-size: 85%;
	margin: -0.5em 0 2em 0;
}

#poststuff .inside .the-tagcloud {
	margin: 5px 0 10px;
	padding: 8px;
	border-width: 1px;
	border-style: solid;
	line-height: 1.8em;
	word-spacing: 3px;
	-moz-border-radius: 6px;
	-khtml-border-radius: 6px;
	-webkit-border-radius: 6px;
	border-radius: 6px;
}

br.clear {
	height: 2px;
	line-height: 2px;
}

.swfupload {
	margin: 5px 10px;
	vertical-align: middle;
}

/* table.fixed column width */
table.fixed {
	table-layout: fixed;
}

.fixed .column-rating,
.fixed .column-visible {
	width: 8%;
}

.fixed .column-date,
.fixed .column-parent,
.fixed .column-links {
	width: 10%;
}

.fixed .column-response,
.fixed .column-author,
.fixed .column-categories,
.fixed .column-tags,
.fixed .column-rel,
.fixed .column-role {
	width: 15%;
}

.fixed .column-comments {
	width: 4em;
	padding-top: 8px;
}

.fixed .column-slug {
	width: 25%;
}

.fixed .column-posts {
	width: 10%;
}

.fixed .column-icon {
	width: 80px;
}

#commentstatusdiv .fixed .column-author,
#comments-form .fixed .column-author,
#commentstatusdiv .fixed .column-date {
	width: 20%;
}

.widefat th,
.widefat td {
	overflow: hidden;
}

.widefat td p {
	margin: 2px 0 0.8em;
}

table .vers,
table .column-visible,
table .column-rating {
	text-align: center;
}

.icon32 {
	float: left;
	height: 36px;
	margin: 14px 6px 0 0;
	width: 36px;
}

.key-labels label {
	line-height: 24px;
}

.subtitle {
	font-size: 0.75em;
	line-height: 1;
	padding-left: 25px;
}

ol {
	list-style-type: decimal;
	margin-left: 2em;
}

.postbox-container {
	float: left;
	padding-right: 0.5%;
}

.postbox-container .meta-box-sortables {
	min-height: 300px;
}

.temp-border {
	border: 1px dotted #ccc;
}

.columns-prefs label {
	padding: 0 5px;
}

.theme-install-php h4,
.plugin-install-php h4 {
	margin: 2.5em 0 8px;
}

p.install-help {
	margin: 8px 0;
	font-style: italic;
}

p.popular-tags {
	-moz-border-radius: 8px;
	-khtml-border-radius: 8px;
	-webkit-border-radius: 8px;
	border-radius: 8px;
	border-width: 1px;
	border-style: solid;
	line-height: 2em;
	padding: 8px 12px 12px;
	text-align: justify;
}

p.popular-tags a {
	padding: 0 3px;
}

.stuffbox .editcomment {
	clear: none;
}

.ajax-feedback {
	visibility: hidden;
	vertical-align: bottom;
}

.tagsdiv .newtag {
	width: 180px;
}

.tagsdiv .the-tags {
	display: block;
	height: 60px;
	margin: 0 auto;
	overflow: auto;
	width: 260px;
}

#post-body-content .tagsdiv .the-tags {
	margin: 0 5px;
}

label,
#your-profile label + a {
	vertical-align: middle;
}

.plugin-update-tr .update-message {
	margin: 5px;
	padding: 3px 5px;
	border-width: 1px;
	border-style: solid;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}
