html {
	background-color: #f7f6f1;
}

* html input,
* html .widget {
    border-color: #8cbdd5;
}

textarea,
input,
select {
	border-color: #dfdfdf;
}

kbd,
code {
	background: #eaeaea;
}

input[readonly] {
	background-color: #eee;
}

.find-box-search {
	border-color: #dfdfdf;
	background-color: #f1f1f1;
}

.find-box {
	background-color: #f1f1f1;
}

.find-box-inside {
	background-color: #fff;
}

a.page-numbers:hover {
	border-color: #999;
}

body,
#wpbody,
.form-table .pre {
	color: #333;
}

body > #upload-menu {
	border-bottom-color: #fff;
}

#postcustomstuff table,
#your-profile fieldset,
#rightnow,
div.dashboard-widget,
#dashboard-widgets p.dashboard-widget-links,
#replyrow #ed_reply_toolbar input {
	border-color: #ccc;
}

#poststuff .inside label.spam {
	color: red;
}

#poststuff .inside label.waiting {
	color: orange;
}

#poststuff .inside label.approved {
	color: green;
}

#postcustomstuff table {
	border-color: #dfdfdf;
	background-color: #f9f9f9;
}

#postcustomstuff thead th {
	background-color: #f1f1f1;
}

#postcustomstuff table input,
#postcustomstuff table textarea {
	border-color: #dfdfdf;
	background-color: #fff;
}

.widefat {
	border-color: #dfdfdf;
	background-color: #fff;
}

div.dashboard-widget-error {
	background-color: #c43;
}

div.dashboard-widget-notice {
	background-color: #cfe1ef;
}

div.dashboard-widget-submit {
	border-top-color: #ccc;
}

div.tabs-panel,
ul#category-tabs li.tabs {
	border-color: #dfdfdf;
}

ul#category-tabs li.tabs {
	background-color: #f1f1f1;
}

input.disabled,
textarea.disabled {
	background-color: #ccc;
}
/* #upload-menu li a.upload-tab-link, */
.login #backtoblog a:hover,
#plugin-information .action-button a,
#plugin-information .action-button a:hover,
#plugin-information .action-button a:visited {
	color: #fff;
}

.widget .widget-top,
.postbox h3,
.stuffbox h3 {
	background: #d5e6f2 url("../images/blue-grad.png") repeat-x left top;
	text-shadow: #fff 0 1px 0;
}

.form-table th,
.form-wrap label {
	color: #222;
	text-shadow: #fff 0 1px 0;
}

.description,
.form-wrap p {
	color: #666;
}

strong .post-com-count span {
	background-color: #21759b;
}

.sorthelper {
	background-color: #ccf3fa;
}

.ac_match,
.subsubsub a.current {
	color: #000;
}

.wrap h2 {
	color: #093e56;
}

.ac_over {
	background-color: #f0f0b8;
}

.ac_results {
	background-color: #fff;
	border-color: #808080;
}

.ac_results li {
	color: #101010;
}

.alt
.alternate {
	background-color: #edfbfc;
}

.available-theme a.screenshot {
	background-color: #f1f1f1;
	border-color: #ddd;
}

.bar {
	background-color: #e8e8e8;
	border-right-color: #99d;
}

#media-upload {
	background: #fff;
}

#media-upload .slidetoggle {
	border-top-color: #dfdfdf;
}

.error,
#login #login_error {
	background-color: #ffebe8;
	border-color: #c00;
}

.error a {
	color: #c00;
}

.form-invalid {
	background-color: #ffebe8 !important;
}

.form-invalid input {
	border-color: #c00 !important;
}

.submit {
	border-color: #8cbdd5;
}

.highlight {
	background-color: #e4f2fd;
	color: #d54e21;
}

.howto,
.nonessential,
#edit-slug-box,
.form-input-tip,
.rss-widget span.rss-date,
.subsubsub {
	color: #666;
}

.media-item {
	border-bottom-color: #dfdfdf;
}

#wpbody-content #media-items .describe {
	border-top-color: #dfdfdf;
}

.describe input[type="text"],
.describe textarea {
	border-color: #dfdfdf;
}

.media-upload-form label.form-help,
td.help {
	color: #9a9a9a;
}

.post-com-count {
	background-image: url(../images/bubble_bg.gif);
	color: #fff;
}

.post-com-count span {
	background-color: #bbb;
	color: #fff;
}

.post-com-count:hover span {
	background-color: #d54e21;
}

.quicktags, .search {
	background-color: #ccc;
	color: #000;
}

.side-info h5 {
	border-bottom-color: #dadada;
}

.side-info ul {
	color: #666;
}

.button,
.button-secondary,
.submit input,
input[type=button],
input[type=submit] {
	border-color: #dfdfdf;
	color: #464646;
}

.button:hover,
.button-secondary:hover,
.submit input:hover,
input[type=button]:hover,
input[type=submit]:hover {
	color: #000;
	border-color: #adaca7;
}

.button,
.submit input,
.button-secondary {
	background: #f2f2f2 url(../images/white-grad.png) repeat-x scroll left top;
}

.button:active,
.submit input:active,
.button-secondary:active {
	background: #eee url(../images/white-grad-active.png) repeat-x scroll left top;
}

.button-primary,
.submit .button-primary,
#login form .submit input {
	border-color: #5b86ab !important;
	font-weight: bold;
	color: #fff !important;
	background: #5580a6 url(../images/button-grad-vs.png) repeat-x scroll left top;
}

.button-primary:active,
#login form .submit input:active {
	background: #21759b url(../images/button-grad-active-vs.png) repeat-x scroll left top !important;
}

.button[disabled],
.button:disabled,
.button-secondary[disabled],
.button-secondary:disabled,
a.button.disabled {
	color: #ccc !important;
	border-color: #ccc;
}

.button-primary[disabled],
.button-primary:disabled {
	color: #80a3d2 !important;
}

a:active,
a:focus {
	color: #d54e21;
}

a:hover,
#wphead #viewsite a:hover,
#adminmenu a:hover,
#adminmenu ul.wp-submenu a:hover,
#the-comment-list .comment a:hover,
#rightnow a:hover,
#login form .submit input:hover,
#media-upload a.del-link:hover,
div.dashboard-widget-submit input:hover,
.subsubsub a:hover,
.subsubsub a.current:hover,
.ui-tabs-nav a:hover,
.plugins .inactive a:hover,
#all-plugins-table .plugins .inactive a:hover,
#search-plugins-table .plugins .inactive a:hover {
	color: #d54e21;
}

#the-comment-list .comment-item,
#dashboard-widgets #dashboard_quick_press form p.submit {
	border-color: #dfdfdf;
}

#dashboard_right_now .table {
	background:#faf9f7 !important;
}

.button-primary:hover,
#login form .submit input:hover {
	border-color: #2e5475 !important;
	color: #eaf2fa !important;
}

#side-sortables #category-tabs .tabs a {
	color: #333;
}

#rightnow .rbutton {
	background-color: #ebebeb;
	color: #264761;
}

.submitbox .submit {
	background-color: #464646;
	color: #ccc;
}

.plugins a.delete:hover,
#all-plugins-table .plugins a.delete:hover,
#search-plugins-table .plugins a.delete:hover,
.submitbox .submitdelete,
a.delete {
	color: #f00;
	border-bottom-color: #f00;
}

.submitbox .submitdelete:hover,
#media-items a.delete:hover {
	color: #fff;
	background-color: #f00;
	border-bottom-color: #f00;
}

#normal-sortables .submitbox .submitdelete:hover {
	color: #000;
	background-color: #f00;
	border-bottom-color: #f00;
}

.tablenav .dots {
	border-color: transparent;
}

.tablenav .next,
.tablenav .prev {
	border-color: transparent;
	color: #21759b;
}

.tablenav .next:hover,
.tablenav .prev:hover {
	border-color: transparent;
	color: #d54e21;
}

.updated,
.login #login_error,
.login .message {
	background-color: #ffffe0;
	border-color: #e6db55;
}

.update-message {
	color: #000000;
}

a.page-numbers {
	border-bottom-color: #b8d3e2;
}

.commentlist li {
	border-bottom-color: #ccc;
}

.widefat td,
.widefat th,
#install-plugins .plugins td,
#install-plugins .plugins th {
	border-color: #dfdfdf;
}

.widefat th {
	text-shadow: rgba(255,255,255,0.8) 0 1px 0;
}

.widefat thead tr th,
.widefat tfoot tr th,
h3.dashboard-widget-title,
h3.dashboard-widget-title span,
h3.dashboard-widget-title small,
.find-box-head {
	color: #333;
	background: #d5e6f2 url(../images/blue-grad.png) repeat-x scroll left top;
}

h3.dashboard-widget-title small a {
	color: #d7d7d7;
}

h3.dashboard-widget-title small a:hover {
	color: #fff;
}

a,
#adminmenu a,
#poststuff #edButtonPreview,
#poststuff #edButtonHTML,
#the-comment-list p.comment-author strong a,
#media-upload a.del-link,
#media-items a.delete,
.plugins a.delete,
.ui-tabs-nav a {
	color: #1c6280;
}

/* Because we don't want visited on these links */
body.press-this .tabs a,
body.press-this .tabs a:hover {
	background-color: #fff;
	border-color: #c6d9e9;
	border-bottom-color: #fff;
	color: #d54e21;
}

#adminmenu #awaiting-mod,
#adminmenu .update-plugins,
#sidemenu a .update-plugins,
#rightnow .reallynow,
#plugin-information .action-button {
	background-color: #d54e21;
	color: #fff;
}

#adminmenu li a:hover #awaiting-mod,
#adminmenu li a:hover .update-plugins,
#sidemenu li a:hover .update-plugins {
	background-color: #264761;
	color: #fff;
}

#adminmenu li.current a #awaiting-mod,
#adminmenu li.current a .update-plugins,
#adminmenu li.wp-has-current-submenu a .update-plugins,
#adminmenu li.wp-has-current-submenu a .update-plugins {
	background-color: #ddd;
	color: #000;
	text-shadow: none;
	-moz-box-shadow: rgba(0,0,0,0.2) 0 -1px 0;
	-khtml-box-shadow: rgba(0,0,0,0.2) 0 -1px 0;
	-webkit-box-shadow: rgba(0,0,0,0.2) 0 -1px 0;
	box-shadow: rgba(0,0,0,0.2) 0 -1px 0;
}

#adminmenu li.current a:hover #awaiting-mod,
#adminmenu li.current a:hover .update-plugins,
#adminmenu li.wp-has-current-submenu a:hover #awaiting-mod,
#adminmenu li.wp-has-current-submenu a:hover .update-plugins {
	background-color: #264761;
	color: #fff;
}

div#media-upload-header,
div#plugin-information-header {
	background-color: #f9f9f9;
	border-bottom-color: #dfdfdf;
}

#currenttheme img {
	border-color: #666;
}

#dashboard_secondary div.dashboard-widget-content ul li a {
	background-color: #f9f9f9;
}

input.readonly, textarea.readonly {
	background-color: #ddd;
}

#ed_toolbar input,
#ed_reply_toolbar input {
	background: #fff url("../images/fade-butt.png") repeat-x 0 -2px;
}

#editable-post-name {
	background-color: #fffbcc;
}

#edit-slug-box strong,
.tablenav .displaying-num,
#submitted-on {
	color: #777;
}

.login #nav a {
	color: #21759b !important;
}

.login #nav a:hover {
	color: #d54e21 !important;
}

#footer,
#footer-upgrade {
	background: #1d507d;
	color: #b6d1e4;
}

#media-items {
	border-color: #dfdfdf;
}

.checkbox,
.side-info,
.plugins tr,
.postbox,
#your-profile #rich_editing {
	background-color: #fff;
}

.plugins .inactive,
.plugins .inactive th,
.plugins .inactive td,
tr.inactive + tr.plugin-update-tr .plugin-update {
	background-color: #ebeeef;
}

.plugin-update-tr .update-message {
	background-color: #fffbe4;
	border-color: #dfdfdf;
}

.plugins .active,
.plugins .active th,
.plugins .active td {
	color: #000;
}

.plugins .inactive a { 
	color: #557799; 	
}

#the-comment-list .unapproved,
#the-comment-list .unapproved th,
#the-comment-list .unapproved td {
	background-color: #ffffe0;
}

#the-comment-list .approve a {
	color: #006505;
}

#the-comment-list .unapprove a {
	color: #d98500;
}

#the-comment-list .delete a {
	color: #bc0b0b;
}

.widget,
#widget-list .widget-top,
.postbox,
#titlediv,
#poststuff .postarea,
.stuffbox {
	border-color: #dfdfdf;
}

.widget,
.postbox {
	background-color: #fff;
}

.ui-sortable .postbox h3 {
	color: #093e56;
}

.widget .widget-top,
.ui-sortable .postbox h3:hover {
	color: #000;
}

.curtime #timestamp {
	background-image: url(../images/date-button.gif);
}

#quicktags #ed_link {
	color: #00f;
}

#rightnow .youhave {
	background-color: #f0f6fb;
}

#rightnow a {
	color: #448abd;
}

.tagchecklist span a,
#bulk-titles div a {
	background: url(../images/xit.gif) no-repeat;
}

.tagchecklist span a:hover,
#bulk-titles div a:hover {
	background: url(../images/xit.gif) no-repeat -10px 0;
}

#update-nag {
	background-color: #fffeeb;
	border-color: #ccc;
	color: #555;
}

.login #backtoblog a {
	color: #ccc;
}

#wphead {
	background-color: #1d507d;
}

body.login {
	border-top-color: #093e56;
}

#wphead h1 a {
	color: #fff;
}

#login form input {
	color: #555;
}

#user_info {
	color: #b6d1e4;
}

#user_info a:link,
#user_info a:visited,
#footer a:link,
#footer a:visited {
	color: #fff;
	text-decoration: none;
}

#user_info a:hover,
#user_info a:active,
#footer a:hover,
#footer a:active  {
	text-decoration: underline;
}

div#media-upload-error,
.file-error,
abbr.required,
.widget-control-remove:hover,
.delete a:hover {
	color: #f00;
}

/* password strength meter */
#pass-strength-result {
	background-color: #eee;
	border-color: #ddd !important;
}

#pass-strength-result.bad {
	background-color: #ffb78c;
	border-color: #ff853c !important;
}

#pass-strength-result.good {
	background-color: #ffec8b;
	border-color: #fc0 !important;
}

#pass-strength-result.short {
	background-color: #ffa0a0;
	border-color: #f04040 !important;
}

#pass-strength-result.strong {
	background-color: #c3ff88;
	border-color: #8dff1c !important;
}

/* editors */
#quicktags {
	border-color: #dfdfdf;
	background-color: #dfdfdf;
}

#ed_toolbar input {
	border-color: #c3c3c3;
}

#ed_toolbar input:hover {
	border-color: #aaa;
	background: #ddd;
}

#poststuff .wp_themeSkin .mceStatusbar {
	border-color: #ededed;
}

#poststuff #edButtonPreview,
#poststuff #edButtonHTML {
	background-color: #f2f1eb;
	border-color: #dfdfdf;
	color: #999;
}

#poststuff #editor-toolbar .active {
	border-bottom-color: #e3eef7;
	background-color: #e3eef7;
	color: #333;
}

/* TinyMCE */
#post-status-info {
	background-color: #ededed;
}

.wp_themeSkin *,
.wp_themeSkin a:hover,
.wp_themeSkin a:link,
.wp_themeSkin a:visited,
.wp_themeSkin a:active {
	color: #000;
}

/* Containers */
.wp_themeSkin iframe {
	background: #fff;
}

/* Layout */
.wp_themeSkin .mceStatusbar {
	color: #000;
	background-color: #f5f5f5;
}

/* Button */
.wp_themeSkin .mceButton {
	background-color: #e9e8e8;
	border-color: #b2b2b2;
}

.wp_themeSkin a.mceButtonEnabled:hover,
.wp_themeSkin a.mceButtonActive,
.wp_themeSkin a.mceButtonSelected {
	background-color: #d5d5d5;
	border-color: #777 !important;
}

.wp_themeSkin .mceButtonDisabled {
	border-color: #ccc !important;
}

/* ListBox */
.wp_themeSkin .mceListBox .mceText,
.wp_themeSkin .mceListBox .mceOpen  {
	border-color: #b2b2b2;
	background-color: #d5d5d5;
}

.wp_themeSkin table.mceListBoxEnabled:hover .mceOpen,
.wp_themeSkin .mceListBoxHover .mceOpen,
.wp_themeSkin .mceListBoxSelected .mceOpen,
.wp_themeSkin .mceListBoxSelected .mceText {
	border-color: #777 !important;
	background-color: #d5d5d5;
}

.wp_themeSkin table.mceListBoxEnabled:hover .mceText,
.wp_themeSkin .mceListBoxHover .mceText {
	border-color: #777 !important;
}

.wp_themeSkin select.mceListBox {
	border-color: #b2b2b2;
	background-color: #fff;
}

/* SplitButton */
.wp_themeSkin .mceSplitButton a.mceAction,
.wp_themeSkin .mceSplitButton a.mceOpen {
	border-color: #b2b2b2;
}

.wp_themeSkin .mceSplitButton a.mceOpen:hover,
.wp_themeSkin .mceSplitButtonSelected a.mceOpen,
.wp_themeSkin table.mceSplitButtonEnabled:hover a.mceAction,
.wp_themeSkin .mceSplitButton a.mceAction:hover {
	background-color: #d5d5d5;
	border-color: #777 !important;
}

.wp_themeSkin .mceSplitButtonActive {
	background-color: #b2b2b2;
}

/* ColorSplitButton */
.wp_themeSkin div.mceColorSplitMenu table {
	background-color: #ebebeb;
	border-color: #b2b2b2;
}

.wp_themeSkin .mceColorSplitMenu a {
	border-color: #b2b2b2;
}

.wp_themeSkin .mceColorSplitMenu a.mceMoreColors {
	border-color: #fff;
}

.wp_themeSkin .mceColorSplitMenu a.mceMoreColors:hover {
	border-color: #0a246a;
	background-color: #b6bdd2;
}

.wp_themeSkin a.mceMoreColors:hover {
	border-color: #0a246a;
}

/* Menu */
.wp_themeSkin .mceMenu {
	border-color: #ddd;
}

.wp_themeSkin .mceMenu table {
	background-color: #ebeaeb;
}

.wp_themeSkin .mceMenu .mceText {
	color: #000;
}

.wp_themeSkin .mceMenu .mceMenuItemEnabled a:hover,
.wp_themeSkin .mceMenu .mceMenuItemActive {
	background-color: #f5f5f5;
}
.wp_themeSkin td.mceMenuItemSeparator {
	background-color: #aaa;
}
.wp_themeSkin .mceMenuItemTitle a {
	background-color: #ccc;
	border-bottom-color: #aaa;
}
.wp_themeSkin .mceMenuItemTitle span.mceText {
	color: #000;
}
.wp_themeSkin .mceMenuItemDisabled .mceText {
	color: #888;
}

#quicktags,
.wp_themeSkin tr.mceFirst td.mceToolbar {
	background: #e3eef7 url("../images/ed-bg-vs.gif") repeat-x scroll left top;
}
.wp_themeSkin tr.mceFirst td.mceToolbar {
	border-color: #dfdfdf;
}

.wp-admin #mceModalBlocker {
	background: #000;
}

.wp-admin .clearlooks2 .mceFocus .mceTop .mceLeft {
	background: #444;
	border-left: 1px solid #999;
	border-top: 1px solid #999;
	-moz-border-radius: 4px 0 0 0;
	-webkit-border-top-left-radius: 4px;
	-khtml-border-top-left-radius: 4px;
	border-top-left-radius: 4px;
}

.wp-admin .clearlooks2 .mceFocus .mceTop .mceRight {
	background: #444;
	border-right: 1px solid #999;
	border-top: 1px solid #999;
	border-top-right-radius: 4px;
	-khtml-border-top-right-radius: 4px;
	-webkit-border-top-right-radius: 4px;
	-moz-border-radius: 0 4px 0 0;
}

.wp-admin .clearlooks2 .mceMiddle .mceLeft {
	background: #f1f1f1;
	border-left: 1px solid #999;
}

.wp-admin .clearlooks2 .mceMiddle .mceRight {
	background: #f1f1f1;
	border-right: 1px solid #999;
}

.wp-admin .clearlooks2 .mceBottom {
	background: #f1f1f1;
	border-bottom: 1px solid #999;
}

.wp-admin .clearlooks2 .mceBottom .mceLeft {
	background: #f1f1f1;
	border-bottom: 1px solid #999;
	border-left: 1px solid #999;
}

.wp-admin .clearlooks2 .mceBottom .mceCenter {
	background: #f1f1f1;
	border-bottom: 1px solid #999;
}

.wp-admin .clearlooks2 .mceBottom .mceRight {
	background: #f1f1f1;
	border-bottom: 1px solid #999;
	border-right: 1px solid #999;
}

.wp-admin .clearlooks2 .mceFocus .mceTop span {
	color: #e5e5e5;
}
/* end TinyMCE */

#editorcontainer,
#post-status-info,
#titlediv #title,
.editwidget .widget-inside {
	border-color: #dfdfdf;
}

#titlediv #title {
	background-color: #fff;
}

#tTips p#tTips_inside {
	background-color: #ddd;
	color: #333;
}

#timestampdiv input,
#namediv input,
#poststuff .inside .the-tagcloud {
	border-color: #dfdfdf;
}

/* menu */
#adminmenu * {
	border-color: #dfdfdf;
}

#adminmenu li.wp-menu-separator {
	background: transparent url(../images/menu-arrows.gif) no-repeat scroll left 5px;
}

.folded #adminmenu li.wp-menu-separator {
	background: transparent url(../images/menu-arrows.gif) no-repeat scroll right -34px;
}

#adminmenu li.wp-has-current-submenu.wp-menu-open .wp-menu-toggle,
#adminmenu li.wp-has-current-submenu:hover .wp-menu-toggle {
	background: transparent url(../images/menu-bits-vs.gif) no-repeat scroll left -207px;
}

#adminmenu .wp-has-submenu:hover .wp-menu-toggle,
#adminmenu .wp-menu-open .wp-menu-toggle {
	background: transparent url(../images/menu-bits-vs.gif) no-repeat scroll left -109px;
}

#adminmenu a.menu-top {
	background: #eaf3fa url(../images/menu-bits-vs.gif) repeat-x scroll left -379px;
}

#adminmenu .wp-submenu a {
	background: #fff url(../images/menu-bits-vs.gif) no-repeat scroll 0 -310px;
}

#adminmenu .wp-has-current-submenu ul li a {
	background: none;
}

#adminmenu .wp-has-current-submenu ul li a.current {
	background: url(../images/menu-dark.gif) top left no-repeat !important;
}

#adminmenu li.wp-has-current-submenu a.wp-has-current-submenu,
#adminmenu .menu-top .current {
	background: #3c6b95 url(../images/menu-bits-vs.gif) top left repeat-x;
	border-color: #1d507d;
	color: #fff;
	text-shadow: rgba(0,0,0,0.4) 0 -1px 0;
}

#adminmenu li.wp-has-current-submenu .wp-submenu,
#adminmenu li.wp-has-current-submenu ul li a {
	border-color: #aaa !important;
}

#adminmenu li.wp-has-current-submenu ul li a {
	background: url(../images/menu-dark.gif) bottom left no-repeat !important;
}

#adminmenu li.wp-has-current-submenu ul {
	border-bottom-color: #aaa;
}

#adminmenu li.menu-top .current:hover {
	border-color: #6583c0;
}

#adminmenu .wp-submenu .current a.current {
	background: transparent url(../images/menu-bits-vs.gif) no-repeat scroll  0 -289px;
}

#adminmenu .wp-submenu a:hover {
	background-color: #eaf2fa !important;
	color: #333 !important;
}

#adminmenu .wp-submenu li.current,
#adminmenu .wp-submenu li.current a,
#adminmenu .wp-submenu li.current a:hover {
	color: #333;
	background-color: #f5f5f5;
	background-image: none;
	border-color: #e3e3e3;
	text-shadow: rgba(255,255,255,1) 0 1px 0;
}

#adminmenu .wp-submenu ul {
	background-color: #fff;
}

.folded #adminmenu li.menu-top,
#adminmenu .wp-submenu .wp-submenu-head {
	background-color: #eaf2fa;
}

.folded #adminmenu li.wp-has-current-submenu,
.folded #adminmenu li.menu-top.current {
	background-color: #bbd8e7;
}

#adminmenu .wp-has-current-submenu .wp-submenu .wp-submenu-head {
	background-color: #bbd8e7;
	border-color: #8cbdd5;
}

#adminmenu div.wp-submenu {
	background-color: transparent;
}

/* menu icons */
#adminmenu #menu-dashboard div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -61px -33px;
}

#adminmenu #menu-dashboard:hover div.wp-menu-image,
#adminmenu  #menu-dashboard.wp-has-current-submenu div.wp-menu-image,
#adminmenu  #menu-dashboard.current div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -61px -1px;
}

#adminmenu #menu-posts div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -272px -33px;
}

#adminmenu #menu-posts:hover div.wp-menu-image,
#adminmenu #menu-posts.wp-has-current-submenu div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -272px -1px;
}

#adminmenu #menu-media div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -121px -33px;
}

#adminmenu #menu-media:hover div.wp-menu-image,
#adminmenu #menu-media.wp-has-current-submenu div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -121px -1px;
}

#adminmenu #menu-links div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -91px -33px;
}

#adminmenu #menu-links:hover div.wp-menu-image,
#adminmenu #menu-links.wp-has-current-submenu div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -91px -1px;
}

#adminmenu #menu-pages div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -151px -33px;
}

#adminmenu #menu-pages:hover div.wp-menu-image,
#adminmenu #menu-pages.wp-has-current-submenu div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -151px -1px;
}

#adminmenu #menu-comments div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -31px -33px;
}

#adminmenu #menu-comments:hover div.wp-menu-image,
#adminmenu #menu-comments.wp-has-current-submenu div.wp-menu-image,
#adminmenu #menu-comments.current div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -31px -1px;
}

#adminmenu #menu-appearance div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -1px -33px;
}

#adminmenu #menu-appearance:hover div.wp-menu-image,
#adminmenu #menu-appearance.wp-has-current-submenu div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -1px -1px;
}

#adminmenu #menu-plugins div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -181px -33px;
}

#adminmenu #menu-plugins:hover div.wp-menu-image,
#adminmenu #menu-plugins.wp-has-current-submenu div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -181px -1px;
}

#adminmenu #menu-users div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -301px -33px;
}

#adminmenu #menu-users:hover div.wp-menu-image,
#adminmenu #menu-users.wp-has-current-submenu div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -301px -1px;
}

#adminmenu #menu-tools div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -211px -33px;
}

#adminmenu #menu-tools:hover div.wp-menu-image,
#adminmenu #menu-tools.wp-has-current-submenu div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -211px -1px;
}

#adminmenu #menu-settings div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -241px -33px;
}

#adminmenu #menu-settings:hover div.wp-menu-image,
#adminmenu #menu-settings.wp-has-current-submenu div.wp-menu-image {
	background: transparent url("../images/menu-vs.png") no-repeat scroll -241px -1px;
}
/* end menu */


/* Diff */
table.diff .diff-deletedline {
	background-color: #fdd;
}

table.diff .diff-deletedline del {
	background-color: #f99;
}

table.diff .diff-addedline {
	background-color: #dfd;
}

table.diff .diff-addedline ins {
	background-color: #9f9;
}

#att-info {
	background-color: #e4f2fd;
}

/* edit image */
#sidemenu a {
	background-color: #f9f9f9;
	border-color: #f9f9f9;
	border-bottom-color: #dfdfdf;
}

#sidemenu a.current {
	background-color: #fff;
	border-color: #dfdfdf #dfdfdf #fff;
	color: #d54e21;
}

#screen-options-wrap,
#contextual-help-wrap {
	background-color: #eae9e4;
	border-color: #dfdfdf;
}

#screen-meta-links a.show-settings {
	color: #606060;
}

#screen-meta-links a.show-settings:hover {
	color: #000;
}

#replysubmit {
	background-color: #f1f1f1;
	border-top-color: #ddd;
}

#replyerror {
	border-color: #ddd;
	background-color: #f9f9f9;
}

#edithead,
#replyhead {
	background-color: #f1f1f1;
}

#ed_reply_toolbar {
	background-color: #e9e9e9;
}

/* table vim shortcuts */
.vim-current,
.vim-current th,
.vim-current td {
	background-color: #e4f2fd !important;
}

/* Install Plugins */
.star-average,
.star.star-rating {
	background-color: #fc0;
}

div.star.select:hover {
	background-color: #d00;
}

#plugin-information .fyi ul {
	background-color: #eaf3fa;
}

#plugin-information .fyi h2.mainheader {
	background-color: #cee1ef;
}

#plugin-information pre,
#plugin-information code {
	background-color: #ededff;
}

#plugin-information pre {
	border: 1px solid #ccc;
}

/* inline editor */
.inline-edit-row fieldset input[type="text"],
.inline-edit-row fieldset textarea,
#bulk-titles,
#replyrow input {
	border-color: #ddd;
}

.inline-editor div.title {
	background-color: #eaf3fa;
}

.inline-editor ul.cat-checklist {
	background-color: #fff;
	border-color: #ddd;
}

.inline-editor .categories .catshow,
.inline-editor .categories .cathide {
	color: #21759b;
}

.inline-editor .quick-edit-save {
	background-color: #f1f1f1;
}

#replyrow #ed_reply_toolbar input:hover {
	border-color: #aaa;
	background: #ddd;
}

fieldset.inline-edit-col-right .inline-edit-col {
	border-color: #dfdfdf;
}

.attention {
	color: #d54e21;
}

.meta-box-sortables .postbox:hover .handlediv {
	background: transparent url(../images/menu-bits-vs.gif) no-repeat scroll left -111px;
}

#major-publishing-actions {
	background: #eaf2fa;
}

.tablenav .tablenav-pages {
	color: #555;
}

.tablenav .tablenav-pages a {
	border-color: #e3e3e3;
	background: #eee url('../images/menu-bits-vs.gif') repeat-x scroll left -379px;
}

.tablenav .tablenav-pages a:hover {
	color: #d54e21;
	border-color: #d54321;
}

.tablenav .tablenav-pages a:active {
	color: #fff !important;
}

.tablenav .tablenav-pages .current {
	background: #dfdfdf;
	border-color: #d3d3d3;
}

#availablethemes,
#availablethemes td {
	border-color: #ddd;
}

#current-theme img {
	border-color: #999;
}

#TB_window #TB_title a.tb-theme-preview-link,
#TB_window #TB_title a.tb-theme-preview-link:visited {
	color: #999;
}

#TB_window #TB_title a.tb-theme-preview-link:hover,
#TB_window #TB_title a.tb-theme-preview-link:focus {
	color: #ccc;
}

.misc-pub-section {
	border-bottom-color: #eee;
}

#minor-publishing {
	border-bottom-color: #ddd;
}

#post-body .misc-pub-section {
	border-right-color: #eee;
}

.post-com-count span {
	background-color: #bbb;
}

.form-table .color-palette td {
	border-color: #fff;
}

.sortable-placeholder {
	border-color: #bbb;
	background-color: #f5f5f5;
}

#post-body ul#category-tabs li.tabs a {
	color: #333;
}

#wp_editimgbtn,
#wp_delimgbtn,
#wp_editgallery,
#wp_delgallery {
	border-color: #999;
	background-color: #eee;
}

#wp_editimgbtn:hover,
#wp_delimgbtn:hover,
#wp_editgallery:hover,
#wp_delgallery:hover {
	border-color: #555;
	background-color: #ccc;
}

#favorite-first {
	background: #5580a6 url(../images/fav-vs.png) repeat-x 0 center;
	border-color: #517ea5 !important;
	border-bottom-color: #416686 !important;
}

#favorite-actions .slide-down {
	background-image: url(../images/fav-top-vs.gif);
	background-position:0 0;
	background-repeat: repeat-x;
}

#favorite-inside {
	border-color: #5b86ac;
	background-color: #5580a6;
}

#favorite-toggle {
	background: transparent url(../images/fav-arrow-vs.gif) no-repeat 0 -4px;
}

#favorite-actions a {
	color: #ddd;
}

#favorite-actions a:hover {
	color: #fff;
}

#favorite-inside a:hover {
	text-decoration: underline;
}

#favorite-actions .slide-down {
	border-bottom-color: #626262;
}

.submit input,
.button,
.button-primary,
.button-secondary,
.button-highlighted,
#postcustomstuff .submit input {
	text-shadow: rgba(255,255,255,1) 0 1px 0;
}

.button-primary,
.submit .button-primary {
	text-shadow: rgba(0,0,0,0.3) 0 -1px 0;
}

#screen-meta a.show-settings {
	background-color: transparent;
	text-shadow: rgba(255,255,255,0.7) 0 1px 0;
}

#icon-edit,
#icon-post {
	background: transparent url(../images/icons32-vs.png) no-repeat -552px -5px;
}

#icon-index {
	background: transparent url(../images/icons32-vs.png) no-repeat -137px -5px;
}

#icon-upload {
	background: transparent url(../images/icons32-vs.png) no-repeat -251px -5px;
}

#icon-link-manager,
#icon-link,
#icon-link-category {
	background: transparent url(../images/icons32-vs.png) no-repeat -190px -5px;
}

#icon-edit-pages,
#icon-page {
	background: transparent url(../images/icons32-vs.png) no-repeat -312px -5px;
}

#icon-edit-comments {
	background: transparent url(../images/icons32-vs.png) no-repeat -72px -5px;
}

#icon-themes {
	background: transparent url(../images/icons32-vs.png) no-repeat -11px -5px;
}

#icon-plugins {
	background: transparent url(../images/icons32-vs.png) no-repeat -370px -5px;
}

#icon-users,
#icon-profile,
#icon-user-edit {
	background: transparent url(../images/icons32-vs.png) no-repeat -600px -5px;
}

#icon-tools,
#icon-admin {
	background: transparent url(../images/icons32-vs.png) no-repeat -432px -5px;
}

#icon-options-general {
	background: transparent url(../images/icons32-vs.png) no-repeat -492px -5px;
}

.view-switch #view-switch-list {
	background: transparent url(../images/list-vs.png) no-repeat 0 0;
}

.view-switch #view-switch-list.current {
	background: transparent url(../images/list-vs.png) no-repeat -40px 0;
}

.view-switch #view-switch-excerpt {
	background: transparent url(../images/list-vs.png) no-repeat -20px 0;
}

.view-switch #view-switch-excerpt.current {
	background: transparent url(../images/list-vs.png) no-repeat -60px 0;
}

#header-logo {
	background: transparent url(../images/wp-logo-vs.gif) no-repeat scroll center center;
}

#wphead #site-visit-button {
	background-color: #3c6b95;
	background-image: url(../images/visit-site-button-grad-vs.gif);
	color: #b6d1e4;
	text-shadow: #3f3f3f 0 -1px 0;
}

#wphead a:hover #site-visit-button {
	color: #fff;
}

#wphead a:focus #site-visit-button,
#wphead a:active #site-visit-button {
	background-position: 0 -27px;
}

.popular-tags,
.feature-filter {
	background-color: #fff;
	border-color: #dfdfdf;
}

#theme-information .action-button {
	border-top-color: #dfdfdf;
}

.theme-listing br.line {
	border-bottom-color: #ccc;
}

div.widgets-sortables,
#widgets-left .inactive {
	background-color: #f1f1f1;
    border-color: #ddd;
}

#available-widgets .widget-holder {
    background-color: #fff;
    border-color: #ddd;
}

#widgets-left .sidebar-name {
	background-color: #aaa;
	background-image: url(../images/ed-bg-vs.gif);
	text-shadow: #FFFFFF 0 1px 0;
	border-color: #dfdfdf;
}

#widgets-right .sidebar-name {
	background-image: url(../images/fav-vs.png);
	text-shadow: #3f3f3f 0 -1px 0;
	background-color: #636363;
	border-color: #636363;
	color: #fff;
}

.sidebar-name:hover,
#removing-widget {
	color: #d54e21;
}

#removing-widget span {
	color: black;
}

#widgets-left .sidebar-name-arrow {
	background: transparent url(../images/menu-bits-vs.gif) no-repeat scroll left -109px;
}

#widgets-right .sidebar-name-arrow {
	background: transparent url(../images/fav-arrow-vs.gif) no-repeat scroll 0 -1px;
}

.in-widget-title {
	color: #606060;
}

.deleting .widget-title * {
	color: #aaa;
}
