/*
 * CodePress color styles for HTML syntax highlighting
 */

b {color:#000080;} /* tags */
ins, ins b, ins s, ins em {color:gray;} /* comments */
s, s b {color:#7777e4;} /* attribute values */
a {color:green;} /* links */
u {color:#E67300;} /* forms */
big {color:#db0000;} /* images */
em, em b {color:#800080;} /* style */
strong {color:#800000;} /* script */
tt i {color:darkblue;font-weight:bold;} /* script reserved words */
