/* Fixes for IE bugs */

input.button,
input.button-secondary,
input.button-highlighted {
	padding: 0;
}

#minor-publishing-actions input,
#major-publishing-actions input {
	min-width: auto;
	padding-left: 0;
	padding-right: 0;
}

#wpbody-content .postbox {
	border: 1px solid #dfdfdf;
}

#wpbody-content .postbox h3 {
	margin-bottom: -1px;
}

* html .inner-sidebar #side-sortables,
* html .postbox-container .meta-box-sortables {
	height: 300px;
}

* html #wpbody-content #screen-options-link-wrap {
	display: inline-block;
	width: 150px;
	text-align: center;
}

* html #wpbody-content #contextual-help-link-wrap {
	display: inline-block;
	width: 100px;
	text-align: center;
}

* html #adminmenu {
	margin-left: -80px;
}

* html .folded #adminmenu {
	margin-left: -22px;
}

* html #wpcontent #adminmenu li.menu-top {
	display: inline;
	padding: 0;
	margin: 0;
}

* html #footer {
	margin: 0;
}

.folded #adminmenu li.menu-top {
	display: block;
	zoom: 100%;
}

ul#adminmenu {
	z-index: 99;
}

#adminmenu li.menu-top a.menu-top {
	min-width: auto;
	width: auto;
}

#wpcontent #adminmenu li.wp-has-current-submenu a.wp-has-submenu {
	font-style: normal;
}

* html #wpcontent #adminmenu .wp-menu-open .wp-menu-toggle {
	background: none;
}

* html #wpcontent #adminmenu .wp-has-submenu .wp-menu-toggle {
	background: url(../images/menu-bits.gif) no-repeat scroll left -109px;
}

* html #wpcontent #adminmenu li.wp-has-current-submenu .wp-menu-toggle {
	background: url(../images/menu-bits.gif) no-repeat scroll left -206px;
}

* html #adminmenu div.wp-menu-image {
	height: 29px;
}

#wpcontent #adminmenu .wp-submenu li {
	padding: 0;
}

#adminmenu,
.wp-submenu,
.wp-submenu li,
.wp-menu-toggle {
	zoom: 100%;
}

.folded #adminmenu li.wp-menu-separator {
	width: 28px;
}

#wpcontent #adminmenu .wp-submenu li.wp-submenu-head {
	padding: 3px 4px 4px 10px;
	zoom: 100%;
}

.folded #adminmenu .menu-top {
	height: 30px;
}

.folded #adminmenu .wp-submenu {
	margin: -1px 0 0 0;
}

#template,
#template div,
#editcat,
#addcat,
* html .stuffbox h3 {
	zoom: 100%;
}

.submitbox {
	margin-top: 10px;
}

/* Inline Editor */
#wpbody-content .quick-edit-row-post .inline-edit-col-left {
	width: 39%;
}

#wpbody-content .inline-edit-row-post .inline-edit-col-center {
	width: 19%;
}

#wpbody-content .quick-edit-row-page .inline-edit-col-left {
	width: 49%;
}

#wpbody-content .bulk-edit-row .inline-edit-col-left {
	width: 29%;
}

.inline-edit-row p.submit {
	zoom: 100%;
}

.inline-edit-row fieldset label span.title {
	display: block;
	float: left;
	width: 5em;
}

.inline-edit-row fieldset label span.input-text-wrap {
	margin-left: 0;
	zoom: 100%;
}

#wpbody-content .inline-edit-row fieldset label span.input-text-wrap input {
	line-height: 130%;
}

#wpbody-content .inline-edit-row .input-text-wrap input {
	width: 95%;
}

#wpbody-content .inline-edit-row .input-text-wrap input.inline-edit-password-input {
	width: 8em;
}
/* end Inline Editor */

input {
	line-height: 1;
}

* html .row-actions {
	visibility: visible;
}

#dashboard-widgets h3 a {
	height: 20px;
	line-height: 20px;
}

#wphead-info {
	float: right;
}

#titlediv #title {
	width: 98%;
}

a.button {
	line-height: 1.4em;
	margin: 1px;
	padding: 4px 6px;
}

* html div.widget-liquid-left,
* html div.widget-liquid-right {
	display: block;
	position: relative;
}

#screen-options-wrap {
	overflow: hidden;
}

#favorite-actions {
	z-index: 12;
}

#favorite-inside,
#favorite-inside a,
.favorite-action {
	zoom: 100%;
}

#the-comment-list .comment-item,
#post-status-info,
#wpwrap,
#wpcontent,
#wrap,
#postdivrich,
#postdiv,
#poststuff,
.metabox-holder,
#titlediv,
#post-body,
#editorcontainer,
.tablenav,
.widget-liquid-left,
.widget-liquid-right,
#widgets-left,
.widgets-sortables,
#dragHelper,
.widget .widget-top,
.widget,
.widget-control-actions,
.tagchecklist,
#col-container,
#col-left,
#col-right,
.fileedit-sub {
	display: block;
	zoom: 100%;
}

p.search-box {
	position: static;
	float: right;
	margin: -3px 0 4px;
}

* html #editorcontainer {
	padding: 0;
}

#editorcontainer #content {
	overflow: auto;
	margin: auto;
	width: 98%;
}

form#template div {
	width: 100%;
}

#ed_toolbar input,
#ed_reply_toolbar input {
	overflow: visible;
	padding: 0 4px;
}

#poststuff h2 {
	font-size: 1.6em;
}

* html #poststuff h2 {
	margin-left: 0;
}

#bh {
	margin: 7px 10px 0 0;
	float: right;
}

/* without this dashboard widgets appear in one column for some screen widths */
div#dashboard-widgets {
	padding-right: 1px;
}

.tagchecklist span, .tagchecklist span a {
	display: inline-block;
	display: block;
}

.tagchecklist span a {
	margin: 4px 0 0 -9px;
}

.tablenav .button-secondary, .nav .button-secondary {
	padding: 0 1px;
	vertical-align: middle;
}

.tablenav select {
	font-size: 13px;
	display: inline-block;
	vertical-align: top;
	margin-top: 2px;
}

table.ie-fixed {
	table-layout: fixed;
}

.widefat tr, .widefat th {
	margin-bottom: 0;
	border-spacing: 0;
}

.widefat th input {
	margin: 0 0 0 5px;
}

.widefat .check-column {
	padding: 6px 0 2px;
}

.widefat tbody th.check-column {
	padding: 4px 0 22px;
}

.widefat {
	empty-cells: show;
	border-collapse: collapse;
}

.tablenav a.button-secondary {
	display: inline-block;
	padding: 2px 5px;
}

* html .stuffbox,
* html .stuffbox input,
* html .stuffbox textarea {
	border: 1px solid #DFDFDF;
}

* html .feature-filter .feature-group li {
	width: 145px;
}

* html .widget-top .widget-title-action a {
    background: url("../images/menu-bits.gif") no-repeat scroll 0 -110px;
}

* html div.widget-liquid-left {
    width: 99%;
}

#wp_inactive_widgets {
	padding-bottom: 8px;
}

* html .widgets-sortables {
	height: 50px;
}

* html a#content_resize {
	right: -2px;
}

* html .widget-title h4 {
	width: 205px;
}

* html #removing-widget .in-widget-title {
	display: none;
}

#available-widgets .widget-holder {
	padding-bottom: 65px;
}

#widgets-left .inactive {
	padding-bottom: 10px;
}

.widget-liquid-right .widget,
#wp_inactive_widgets .widget {
	position: relative;
}

