.postbox p, .postbox ul, .postbox ol, .postbox blockquote, #wp-version-message { font-size: 11px; }

.edit-box {
	display: none;
}

h3:hover .edit-box {
	display: inline;
}

form .input-text-wrap {
	border-style: solid;
	border-width: 1px;
	padding: 2px 3px;
	border-color: #ccc;
}

#dashboard-widgets form .input-text-wrap input {
	border: 0 none;
	outline: none;
	margin: 0;
	padding: 0;
	width: 99%;
	color: #333;
}

form .textarea-wrap {
	border-style: solid;
	border-width: 1px;
	padding: 2px;
	border-color: #ccc;
}

#dashboard-widgets form .textarea-wrap textarea {
	border: 0 none;
	padding: 0;
	outline: none;
	width: 99%;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
}

#dashboard-widgets .postbox form .submit {
	float: none;
	margin: .5em 0 0;
	padding: 0;
	border: none;
}

#dashboard-widgets-wrap #dashboard-widgets .postbox form .submit input {
	margin: 0;
}

#dashboard-widgets-wrap #dashboard-widgets .postbox form .submit #publish {
	min-width: 0;
}

div.postbox div.inside {
	margin: 10px;
	position: relative;
}

#dashboard-widgets a {
	text-decoration: none;
}

#dashboard-widgets h3 a {
	text-decoration: underline;
}

#dashboard-widgets h3 .postbox-title-action {
	position: absolute;
	right: 30px;
	padding: 0;
}

#dashboard-widgets h4 {
	font-family: Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
	font-size: 13px;
	margin: 0 0 .2em;
	padding: 0;
}

/* Right Now */

#dashboard_right_now p.sub,
#dashboard_right_now .table, #dashboard_right_now .versions {
	margin: -12px;
}

#dashboard_right_now .inside {
	font-size: 12px;
}

#dashboard_right_now p.sub {
	font-style: italic;
	font-family: Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
	padding: 5px 10px 15px;
	color: #777;
	font-size: 13px;
}

#dashboard_right_now .table {
	background: #f9f9f9;
	border-top: #ececec 1px solid;
	border-bottom: #ececec 1px solid;
	margin: 0 -9px 10px;
	padding: 0 10px;
}

#dashboard_right_now table {
	width: 100%;
}

#dashboard_right_now table  td {
	border-top: #ececec 1px solid;
	padding: 3px 0;
	white-space: nowrap;
}

#dashboard_right_now table tr.first td {
	border-top: none;
}

#dashboard_right_now td.b {
	padding-right: 6px;
	text-align: right;
	font-family: Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
	font-size: 14px;
}

#dashboard_right_now td.b a {
	font-size: 18px;
}

#dashboard_right_now td.b a:hover {
	color: #d54e21;
}

#dashboard_right_now .t {
	font-size: 12px;
	padding-right: 12px;
	padding-top: 6px;
	color: #777;
}

#dashboard_right_now td.first,
#dashboard_right_now td.last {
	width: 1px;
}

#dashboard_right_now .spam {
	color: red;
}

#dashboard_right_now .waiting {
	color: #e66f00;
}

#dashboard_right_now .approved {
	color: green;
}

#dashboard_right_now .versions {
	padding: 6px 10px 12px;
}

#dashboard_right_now .versions .b {
	font-weight: bold;
}

#dashboard_right_now a.button {
	float: right;
	clear: right;
	position: relative;
	top: -5px;
}

/* Recent Comments */

#dashboard_recent_comments h3 {
	margin-bottom: 0;
}

#dashboard_recent_comments .inside {
	margin-top: 0;
}

#dashboard_recent_comments .comment-meta .approve {
	font-style: italic;
	font-family: "Lucida Grande", Verdana, Arial, "Bitstream Vera Sans", sans-serif;
	font-size: 10px;
}

#the-comment-list {
	position: relative;
}

#the-comment-list .comment-item {
	padding: 1em 10px;
	border-top: 1px solid;
}

#the-comment-list .pingback {
	padding-left: 9px !important;
}

#the-comment-list .comment-item,
#the-comment-list #replyrow {
	margin: 0 -10px;
}

#the-comment-list .comment-item:first-child {
	border-top: none;
}

#the-comment-list .comment-item .avatar {
	float: left;
	margin: 0 10px 5px 0;
}

#the-comment-list .comment-item h4 {
	line-height: 1.4;
	margin-top: -.2em;
	font-weight: normal;
	color: #999;
}

#the-comment-list .comment-item h4 cite {
	font-style: normal;
	font-weight: normal;
}

#the-comment-list .comment-item blockquote,
#the-comment-list .comment-item blockquote p {
	margin: 0;
	padding: 0;
	display: inline;
}

#dashboard_recent_comments #the-comment-list .trackback blockquote,
#dashboard_recent_comments #the-comment-list .pingback blockquote {
	display: block;
}

#the-comment-list .comment-item p.row-actions {
	margin: 3px 0 0;
	padding: 0;
	font-size: 10px;
}

/* QuickPress */

#dashboard_quick_press h4 {
	font-family: "Lucida Grande", Verdana, Arial, "Bitstream Vera Sans", sans-serif;
	float: left;
	width: 5.5em;
	clear: both;
	font-weight: normal;
	text-align: right;
	padding-top: 5px;
	font-size: 12px;
}

#dashboard_quick_press h4 label {
	margin-right: 10px;
}

#dashboard_quick_press .input-text-wrap,
#dashboard_quick_press .textarea-wrap {
	margin: 0 0 1em 5em;
}

#dashboard_quick_press #media-buttons {
	margin: 0 0 .5em 5em;
	padding: 0 0 0 10px;
	font-size: 11px;
}

#dashboard_quick_press #media-buttons a {
	vertical-align: bottom;
}

#dashboard-widgets #dashboard_quick_press form p.submit {
	margin-left: 4.6em;
}

#dashboard-widgets #dashboard_quick_press form p.submit input {
	float: left;
}

#dashboard-widgets #dashboard_quick_press form p.submit #save-post {
	margin: 0 1em 0 10px;
}

#dashboard-widgets #dashboard_quick_press form p.submit #publish {
	float: right;
}

/* Recent Drafts */
#dashboard_recent_drafts ul {
	margin: 0;
	padding: 0;
	list-style: none;
}

#dashboard_recent_drafts ul li {
	margin-bottom: 0.6em;
}

#dashboard_recent_drafts h4 {
	font-weight: normal;
}

#dashboard_recent_drafts h4 abbr {
	font-family: "Lucida Grande", Verdana, Arial, "Bitstream Vera Sans", sans-serif;
	font-size: 11px;
	color: #999;
	margin-left: 3px;
}

#dashboard_recent_drafts p {
	margin: 0;
	padding: 0;
}

/* Feeds */

.rss-widget ul {
	margin: 0;
	padding: 0;
	list-style: none;
}

a.rsswidget {
	font-size: 13px;
	font-family: Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
	line-height: 1.7em;
}

.rss-widget ul li {
	line-height: 1.5em;
	margin-bottom: 12px;
}

.rss-widget span.rss-date {
	margin-left: 3px;
}

.rss-widget cite {
	display: block;
	text-align: right;
	margin: 0 0 1em;
	padding: 0;
}

.rss-widget cite:before {
	content: '\2014';
}

/* Plugins */

#dashboard_plugins h4 {
	font-family: "Lucida Grande", Verdana, Arial, "Bitstream Vera Sans", sans-serif;
}

#dashboard_plugins h5 {
	font-family: Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
	font-size: 13px !important;
	margin: 0;
	display: inline;
	line-height: 1.4em;
}

#dashboard_plugins h5 a {
	font-weight: normal;
	line-height: 1.7em;
}

#dashboard_plugins p {
	margin: 0 0 1.4em;
	line-height: 1.4em;
}

.dashboard-comment-wrap {
	overflow: hidden;
	word-wrap: break-word;
}

