/*
 * CodePress color styles for Perl syntax highlighting
 * By J. Nick Koston
 */

b {color:#7F0055;font-weight:bold;} /* reserved words */
i, i b, i s, i em, i a, i u {color:gray;font-weight:normal;} /* comments */
s, s b, s a, s em, s u {color:#2A00FF;font-weight:normal;} /* strings */
a {color:#006700;font-weight:bold;} /* variables */
em {color:darkblue;font-weight:bold;} /* functions */
u {font-weight:bold;} /* special chars */