<?php
/**
 * Deprecated. Use registration.php.
 *
 * @package WordPress
 */
_deprecated_file( basename(__FILE__), '0.0', 'registration.php' );
require_once(ABSPATH . WPINC .  '/registration.php');
?>
